from __future__ import annotations

# DO NOT EDIT!
# This file was automatically generated by "generate_ids.py"
import enum


class UnitTypeId(enum.Enum):
    NOTAUNIT = 0
    SYSTEM_SNAPSHOT_DUMMY = 1
    BALL = 2
    STEREOSCOPICOPTIONSUNIT = 3
    COLOSSUS = 4
    TECHLAB = 5
    REACTOR = 6
    INFESTORTERRAN = 7
    BANELINGCOCOON = 8
    BANELING = 9
    MOTHERSHIP = 10
    POINTDEFENSEDRONE = 11
    CHANGELING = 12
    CHANGELINGZEALOT = 13
    CHANGELINGMARINESHIELD = 14
    CHANGELINGMARINE = 15
    CHANGELINGZERGLINGWINGS = 16
    CHANGELINGZERGLING = 17
    COMMANDCENTER = 18
    SUPPLYDEPOT = 19
    REFINERY = 20
    BARRACKS = 21
    ENGINEERINGBAY = 22
    MISSILETURRET = 23
    BUNKER = 24
    SENSORTOWER = 25
    GHOSTACADEMY = 26
    FACTORY = 27
    STARPORT = 28
    ARMORY = 29
    FUSIONCORE = 30
    AUTOTURRET = 31
    SIEGETANKSIEGED = 32
    SIEGETANK = 33
    VIKINGASSAULT = 34
    VIKINGFIGHTER = 35
    COMMANDCENTERFLYING = 36
    BARRACKSTECHLAB = 37
    BARRACKSREACTOR = 38
    FACTORYTECHLAB = 39
    FACTORYREACTOR = 40
    STARPORTTECHLAB = 41
    STARPORTREACTOR = 42
    FACTORYFLYING = 43
    STARPORTFLYING = 44
    SCV = 45
    BARRACKSFLYING = 46
    SUPPLYDEPOTLOWERED = 47
    MARINE = 48
    REAPER = 49
    GHOST = 50
    MARAUDER = 51
    THOR = 52
    HELLION = 53
    MEDIVAC = 54
    BANSHEE = 55
    RAVEN = 56
    BATTLECRUISER = 57
    NUKE = 58
    NEXUS = 59
    PYLON = 60
    ASSIMILATOR = 61
    GATEWAY = 62
    FORGE = 63
    FLEETBEACON = 64
    TWILIGHTCOUNCIL = 65
    PHOTONCANNON = 66
    STARGATE = 67
    TEMPLARARCHIVE = 68
    DARKSHRINE = 69
    ROBOTICSBAY = 70
    ROBOTICSFACILITY = 71
    CYBERNETICSCORE = 72
    ZEALOT = 73
    STALKER = 74
    HIGHTEMPLAR = 75
    DARKTEMPLAR = 76
    SENTRY = 77
    PHOENIX = 78
    CARRIER = 79
    VOIDRAY = 80
    WARPPRISM = 81
    OBSERVER = 82
    IMMORTAL = 83
    PROBE = 84
    INTERCEPTOR = 85
    HATCHERY = 86
    CREEPTUMOR = 87
    EXTRACTOR = 88
    SPAWNINGPOOL = 89
    EVOLUTIONCHAMBER = 90
    HYDRALISKDEN = 91
    SPIRE = 92
    ULTRALISKCAVERN = 93
    INFESTATIONPIT = 94
    NYDUSNETWORK = 95
    BANELINGNEST = 96
    ROACHWARREN = 97
    SPINECRAWLER = 98
    SPORECRAWLER = 99
    LAIR = 100
    HIVE = 101
    GREATERSPIRE = 102
    EGG = 103
    DRONE = 104
    ZERGLING = 105
    OVERLORD = 106
    HYDRALISK = 107
    MUTALISK = 108
    ULTRALISK = 109
    ROACH = 110
    INFESTOR = 111
    CORRUPTOR = 112
    BROODLORDCOCOON = 113
    BROODLORD = 114
    BANELINGBURROWED = 115
    DRONEBURROWED = 116
    HYDRALISKBURROWED = 117
    ROACHBURROWED = 118
    ZERGLINGBURROWED = 119
    INFESTORTERRANBURROWED = 120
    REDSTONELAVACRITTERBURROWED = 121
    REDSTONELAVACRITTERINJUREDBURROWED = 122
    REDSTONELAVACRITTER = 123
    REDSTONELAVACRITTERINJURED = 124
    QUEENBURROWED = 125
    QUEEN = 126
    INFESTORBURROWED = 127
    OVERLORDCOCOON = 128
    OVERSEER = 129
    PLANETARYFORTRESS = 130
    ULTRALISKBURROWED = 131
    ORBITALCOMMAND = 132
    WARPGATE = 133
    ORBITALCOMMANDFLYING = 134
    FORCEFIELD = 135
    WARPPRISMPHASING = 136
    CREEPTUMORBURROWED = 137
    CREEPTUMORQUEEN = 138
    SPINECRAWLERUPROOTED = 139
    SPORECRAWLERUPROOTED = 140
    ARCHON = 141
    NYDUSCANAL = 142
    BROODLINGESCORT = 143
    GHOSTALTERNATE = 144
    GHOSTNOVA = 145
    RICHMINERALFIELD = 146
    RICHMINERALFIELD750 = 147
    URSADON = 148
    XELNAGATOWER = 149
    INFESTEDTERRANSEGG = 150
    LARVA = 151
    REAPERPLACEHOLDER = 152
    MARINEACGLUESCREENDUMMY = 153
    FIREBATACGLUESCREENDUMMY = 154
    MEDICACGLUESCREENDUMMY = 155
    MARAUDERACGLUESCREENDUMMY = 156
    VULTUREACGLUESCREENDUMMY = 157
    SIEGETANKACGLUESCREENDUMMY = 158
    VIKINGACGLUESCREENDUMMY = 159
    BANSHEEACGLUESCREENDUMMY = 160
    BATTLECRUISERACGLUESCREENDUMMY = 161
    ORBITALCOMMANDACGLUESCREENDUMMY = 162
    BUNKERACGLUESCREENDUMMY = 163
    BUNKERUPGRADEDACGLUESCREENDUMMY = 164
    MISSILETURRETACGLUESCREENDUMMY = 165
    HELLBATACGLUESCREENDUMMY = 166
    GOLIATHACGLUESCREENDUMMY = 167
    CYCLONEACGLUESCREENDUMMY = 168
    WRAITHACGLUESCREENDUMMY = 169
    SCIENCEVESSELACGLUESCREENDUMMY = 170
    HERCULESACGLUESCREENDUMMY = 171
    THORACGLUESCREENDUMMY = 172
    PERDITIONTURRETACGLUESCREENDUMMY = 173
    FLAMINGBETTYACGLUESCREENDUMMY = 174
    DEVASTATIONTURRETACGLUESCREENDUMMY = 175
    BLASTERBILLYACGLUESCREENDUMMY = 176
    SPINNINGDIZZYACGLUESCREENDUMMY = 177
    ZERGLINGKERRIGANACGLUESCREENDUMMY = 178
    RAPTORACGLUESCREENDUMMY = 179
    QUEENCOOPACGLUESCREENDUMMY = 180
    HYDRALISKACGLUESCREENDUMMY = 181
    HYDRALISKLURKERACGLUESCREENDUMMY = 182
    MUTALISKBROODLORDACGLUESCREENDUMMY = 183
    BROODLORDACGLUESCREENDUMMY = 184
    ULTRALISKACGLUESCREENDUMMY = 185
    TORRASQUEACGLUESCREENDUMMY = 186
    OVERSEERACGLUESCREENDUMMY = 187
    LURKERACGLUESCREENDUMMY = 188
    SPINECRAWLERACGLUESCREENDUMMY = 189
    SPORECRAWLERACGLUESCREENDUMMY = 190
    NYDUSNETWORKACGLUESCREENDUMMY = 191
    OMEGANETWORKACGLUESCREENDUMMY = 192
    ZERGLINGZAGARAACGLUESCREENDUMMY = 193
    SWARMLINGACGLUESCREENDUMMY = 194
    BANELINGACGLUESCREENDUMMY = 195
    SPLITTERLINGACGLUESCREENDUMMY = 196
    ABERRATIONACGLUESCREENDUMMY = 197
    SCOURGEACGLUESCREENDUMMY = 198
    CORRUPTORACGLUESCREENDUMMY = 199
    BILELAUNCHERACGLUESCREENDUMMY = 200
    SWARMQUEENACGLUESCREENDUMMY = 201
    ROACHACGLUESCREENDUMMY = 202
    ROACHVILEACGLUESCREENDUMMY = 203
    RAVAGERACGLUESCREENDUMMY = 204
    SWARMHOSTACGLUESCREENDUMMY = 205
    MUTALISKACGLUESCREENDUMMY = 206
    GUARDIANACGLUESCREENDUMMY = 207
    DEVOURERACGLUESCREENDUMMY = 208
    VIPERACGLUESCREENDUMMY = 209
    BRUTALISKACGLUESCREENDUMMY = 210
    LEVIATHANACGLUESCREENDUMMY = 211
    ZEALOTACGLUESCREENDUMMY = 212
    ZEALOTAIURACGLUESCREENDUMMY = 213
    DRAGOONACGLUESCREENDUMMY = 214
    HIGHTEMPLARACGLUESCREENDUMMY = 215
    ARCHONACGLUESCREENDUMMY = 216
    IMMORTALACGLUESCREENDUMMY = 217
    OBSERVERACGLUESCREENDUMMY = 218
    PHOENIXAIURACGLUESCREENDUMMY = 219
    REAVERACGLUESCREENDUMMY = 220
    TEMPESTACGLUESCREENDUMMY = 221
    PHOTONCANNONACGLUESCREENDUMMY = 222
    ZEALOTVORAZUNACGLUESCREENDUMMY = 223
    ZEALOTSHAKURASACGLUESCREENDUMMY = 224
    STALKERSHAKURASACGLUESCREENDUMMY = 225
    DARKTEMPLARSHAKURASACGLUESCREENDUMMY = 226
    CORSAIRACGLUESCREENDUMMY = 227
    VOIDRAYACGLUESCREENDUMMY = 228
    VOIDRAYSHAKURASACGLUESCREENDUMMY = 229
    ORACLEACGLUESCREENDUMMY = 230
    DARKARCHONACGLUESCREENDUMMY = 231
    DARKPYLONACGLUESCREENDUMMY = 232
    ZEALOTPURIFIERACGLUESCREENDUMMY = 233
    SENTRYPURIFIERACGLUESCREENDUMMY = 234
    IMMORTALKARAXACGLUESCREENDUMMY = 235
    COLOSSUSACGLUESCREENDUMMY = 236
    COLOSSUSPURIFIERACGLUESCREENDUMMY = 237
    PHOENIXPURIFIERACGLUESCREENDUMMY = 238
    CARRIERACGLUESCREENDUMMY = 239
    CARRIERAIURACGLUESCREENDUMMY = 240
    KHAYDARINMONOLITHACGLUESCREENDUMMY = 241
    SHIELDBATTERYACGLUESCREENDUMMY = 242
    ELITEMARINEACGLUESCREENDUMMY = 243
    MARAUDERCOMMANDOACGLUESCREENDUMMY = 244
    SPECOPSGHOSTACGLUESCREENDUMMY = 245
    HELLBATRANGERACGLUESCREENDUMMY = 246
    STRIKEGOLIATHACGLUESCREENDUMMY = 247
    HEAVYSIEGETANKACGLUESCREENDUMMY = 248
    RAIDLIBERATORACGLUESCREENDUMMY = 249
    RAVENTYPEIIACGLUESCREENDUMMY = 250
    COVERTBANSHEEACGLUESCREENDUMMY = 251
    RAILGUNTURRETACGLUESCREENDUMMY = 252
    BLACKOPSMISSILETURRETACGLUESCREENDUMMY = 253
    SUPPLICANTACGLUESCREENDUMMY = 254
    STALKERTALDARIMACGLUESCREENDUMMY = 255
    SENTRYTALDARIMACGLUESCREENDUMMY = 256
    HIGHTEMPLARTALDARIMACGLUESCREENDUMMY = 257
    IMMORTALTALDARIMACGLUESCREENDUMMY = 258
    COLOSSUSTALDARIMACGLUESCREENDUMMY = 259
    WARPPRISMTALDARIMACGLUESCREENDUMMY = 260
    PHOTONCANNONTALDARIMACGLUESCREENDUMMY = 261
    NEEDLESPINESWEAPON = 262
    CORRUPTIONWEAPON = 263
    INFESTEDTERRANSWEAPON = 264
    NEURALPARASITEWEAPON = 265
    POINTDEFENSEDRONERELEASEWEAPON = 266
    HUNTERSEEKERWEAPON = 267
    MULE = 268
    THORAAWEAPON = 269
    PUNISHERGRENADESLMWEAPON = 270
    VIKINGFIGHTERWEAPON = 271
    ATALASERBATTERYLMWEAPON = 272
    ATSLASERBATTERYLMWEAPON = 273
    LONGBOLTMISSILEWEAPON = 274
    D8CHARGEWEAPON = 275
    YAMATOWEAPON = 276
    IONCANNONSWEAPON = 277
    ACIDSALIVAWEAPON = 278
    SPINECRAWLERWEAPON = 279
    SPORECRAWLERWEAPON = 280
    GLAIVEWURMWEAPON = 281
    GLAIVEWURMM2WEAPON = 282
    GLAIVEWURMM3WEAPON = 283
    STALKERWEAPON = 284
    EMP2WEAPON = 285
    BACKLASHROCKETSLMWEAPON = 286
    PHOTONCANNONWEAPON = 287
    PARASITESPOREWEAPON = 288
    BROODLING = 289
    BROODLORDBWEAPON = 290
    AUTOTURRETRELEASEWEAPON = 291
    LARVARELEASEMISSILE = 292
    ACIDSPINESWEAPON = 293
    FRENZYWEAPON = 294
    CONTAMINATEWEAPON = 295
    BEACONRALLY = 296
    BEACONARMY = 297
    BEACONATTACK = 298
    BEACONDEFEND = 299
    BEACONHARASS = 300
    BEACONIDLE = 301
    BEACONAUTO = 302
    BEACONDETECT = 303
    BEACONSCOUT = 304
    BEACONCLAIM = 305
    BEACONEXPAND = 306
    BEACONCUSTOM1 = 307
    BEACONCUSTOM2 = 308
    BEACONCUSTOM3 = 309
    BEACONCUSTOM4 = 310
    ADEPT = 311
    ROCKS2X2NONCONJOINED = 312
    FUNGALGROWTHMISSILE = 313
    NEURALPARASITETENTACLEMISSILE = 314
    BEACON_PROTOSS = 315
    BEACON_PROTOSSSMALL = 316
    BEACON_TERRAN = 317
    BEACON_TERRANSMALL = 318
    BEACON_ZERG = 319
    BEACON_ZERGSMALL = 320
    LYOTE = 321
    CARRIONBIRD = 322
    KARAKMALE = 323
    KARAKFEMALE = 324
    URSADAKFEMALEEXOTIC = 325
    URSADAKMALE = 326
    URSADAKFEMALE = 327
    URSADAKCALF = 328
    URSADAKMALEEXOTIC = 329
    UTILITYBOT = 330
    COMMENTATORBOT1 = 331
    COMMENTATORBOT2 = 332
    COMMENTATORBOT3 = 333
    COMMENTATORBOT4 = 334
    SCANTIPEDE = 335
    DOG = 336
    SHEEP = 337
    COW = 338
    INFESTEDTERRANSEGGPLACEMENT = 339
    INFESTORTERRANSWEAPON = 340
    MINERALFIELD = 341
    VESPENEGEYSER = 342
    SPACEPLATFORMGEYSER = 343
    RICHVESPENEGEYSER = 344
    DESTRUCTIBLESEARCHLIGHT = 345
    DESTRUCTIBLEBULLHORNLIGHTS = 346
    DESTRUCTIBLESTREETLIGHT = 347
    DESTRUCTIBLESPACEPLATFORMSIGN = 348
    DESTRUCTIBLESTOREFRONTCITYPROPS = 349
    DESTRUCTIBLEBILLBOARDTALL = 350
    DESTRUCTIBLEBILLBOARDSCROLLINGTEXT = 351
    DESTRUCTIBLESPACEPLATFORMBARRIER = 352
    DESTRUCTIBLESIGNSDIRECTIONAL = 353
    DESTRUCTIBLESIGNSCONSTRUCTION = 354
    DESTRUCTIBLESIGNSFUNNY = 355
    DESTRUCTIBLESIGNSICONS = 356
    DESTRUCTIBLESIGNSWARNING = 357
    DESTRUCTIBLEGARAGE = 358
    DESTRUCTIBLEGARAGELARGE = 359
    DESTRUCTIBLETRAFFICSIGNAL = 360
    TRAFFICSIGNAL = 361
    BRAXISALPHADESTRUCTIBLE1X1 = 362
    BRAXISALPHADESTRUCTIBLE2X2 = 363
    DESTRUCTIBLEDEBRIS4X4 = 364
    DESTRUCTIBLEDEBRIS6X6 = 365
    DESTRUCTIBLEROCK2X4VERTICAL = 366
    DESTRUCTIBLEROCK2X4HORIZONTAL = 367
    DESTRUCTIBLEROCK2X6VERTICAL = 368
    DESTRUCTIBLEROCK2X6HORIZONTAL = 369
    DESTRUCTIBLEROCK4X4 = 370
    DESTRUCTIBLEROCK6X6 = 371
    DESTRUCTIBLERAMPDIAGONALHUGEULBR = 372
    DESTRUCTIBLERAMPDIAGONALHUGEBLUR = 373
    DESTRUCTIBLERAMPVERTICALHUGE = 374
    DESTRUCTIBLERAMPHORIZONTALHUGE = 375
    DESTRUCTIBLEDEBRISRAMPDIAGONALHUGEULBR = 376
    DESTRUCTIBLEDEBRISRAMPDIAGONALHUGEBLUR = 377
    OVERLORDGENERATECREEPKEYBIND = 378
    MENGSKSTATUEALONE = 379
    MENGSKSTATUE = 380
    WOLFSTATUE = 381
    GLOBESTATUE = 382
    WEAPON = 383
    GLAIVEWURMBOUNCEWEAPON = 384
    BROODLORDWEAPON = 385
    BROODLORDAWEAPON = 386
    CREEPBLOCKER1X1 = 387
    PERMANENTCREEPBLOCKER1X1 = 388
    PATHINGBLOCKER1X1 = 389
    PATHINGBLOCKER2X2 = 390
    AUTOTESTATTACKTARGETGROUND = 391
    AUTOTESTATTACKTARGETAIR = 392
    AUTOTESTATTACKER = 393
    HELPEREMITTERSELECTIONARROW = 394
    MULTIKILLOBJECT = 395
    SHAPEGOLFBALL = 396
    SHAPECONE = 397
    SHAPECUBE = 398
    SHAPECYLINDER = 399
    SHAPEDODECAHEDRON = 400
    SHAPEICOSAHEDRON = 401
    SHAPEOCTAHEDRON = 402
    SHAPEPYRAMID = 403
    SHAPEROUNDEDCUBE = 404
    SHAPESPHERE = 405
    SHAPETETRAHEDRON = 406
    SHAPETHICKTORUS = 407
    SHAPETHINTORUS = 408
    SHAPETORUS = 409
    SHAPE4POINTSTAR = 410
    SHAPE5POINTSTAR = 411
    SHAPE6POINTSTAR = 412
    SHAPE8POINTSTAR = 413
    SHAPEARROWPOINTER = 414
    SHAPEBOWL = 415
    SHAPEBOX = 416
    SHAPECAPSULE = 417
    SHAPECRESCENTMOON = 418
    SHAPEDECAHEDRON = 419
    SHAPEDIAMOND = 420
    SHAPEFOOTBALL = 421
    SHAPEGEMSTONE = 422
    SHAPEHEART = 423
    SHAPEJACK = 424
    SHAPEPLUSSIGN = 425
    SHAPESHAMROCK = 426
    SHAPESPADE = 427
    SHAPETUBE = 428
    SHAPEEGG = 429
    SHAPEYENSIGN = 430
    SHAPEX = 431
    SHAPEWATERMELON = 432
    SHAPEWONSIGN = 433
    SHAPETENNISBALL = 434
    SHAPESTRAWBERRY = 435
    SHAPESMILEYFACE = 436
    SHAPESOCCERBALL = 437
    SHAPERAINBOW = 438
    SHAPESADFACE = 439
    SHAPEPOUNDSIGN = 440
    SHAPEPEAR = 441
    SHAPEPINEAPPLE = 442
    SHAPEORANGE = 443
    SHAPEPEANUT = 444
    SHAPEO = 445
    SHAPELEMON = 446
    SHAPEMONEYBAG = 447
    SHAPEHORSESHOE = 448
    SHAPEHOCKEYSTICK = 449
    SHAPEHOCKEYPUCK = 450
    SHAPEHAND = 451
    SHAPEGOLFCLUB = 452
    SHAPEGRAPE = 453
    SHAPEEUROSIGN = 454
    SHAPEDOLLARSIGN = 455
    SHAPEBASKETBALL = 456
    SHAPECARROT = 457
    SHAPECHERRY = 458
    SHAPEBASEBALL = 459
    SHAPEBASEBALLBAT = 460
    SHAPEBANANA = 461
    SHAPEAPPLE = 462
    SHAPECASHLARGE = 463
    SHAPECASHMEDIUM = 464
    SHAPECASHSMALL = 465
    SHAPEFOOTBALLCOLORED = 466
    SHAPELEMONSMALL = 467
    SHAPEORANGESMALL = 468
    SHAPETREASURECHESTOPEN = 469
    SHAPETREASURECHESTCLOSED = 470
    SHAPEWATERMELONSMALL = 471
    UNBUILDABLEROCKSDESTRUCTIBLE = 472
    UNBUILDABLEBRICKSDESTRUCTIBLE = 473
    UNBUILDABLEPLATESDESTRUCTIBLE = 474
    DEBRIS2X2NONCONJOINED = 475
    ENEMYPATHINGBLOCKER1X1 = 476
    ENEMYPATHINGBLOCKER2X2 = 477
    ENEMYPATHINGBLOCKER4X4 = 478
    ENEMYPATHINGBLOCKER8X8 = 479
    ENEMYPATHINGBLOCKER16X16 = 480
    SCOPETEST = 481
    SENTRYACGLUESCREENDUMMY = 482
    MINERALFIELD750 = 483
    HELLIONTANK = 484
    COLLAPSIBLETERRANTOWERDEBRIS = 485
    DEBRISRAMPLEFT = 486
    DEBRISRAMPRIGHT = 487
    MOTHERSHIPCORE = 488
    LOCUSTMP = 489
    COLLAPSIBLEROCKTOWERDEBRIS = 490
    NYDUSCANALATTACKER = 491
    NYDUSCANALCREEPER = 492
    SWARMHOSTBURROWEDMP = 493
    SWARMHOSTMP = 494
    ORACLE = 495
    TEMPEST = 496
    WARHOUND = 497
    WIDOWMINE = 498
    VIPER = 499
    WIDOWMINEBURROWED = 500
    LURKERMPEGG = 501
    LURKERMP = 502
    LURKERMPBURROWED = 503
    LURKERDENMP = 504
    EXTENDINGBRIDGENEWIDE8OUT = 505
    EXTENDINGBRIDGENEWIDE8 = 506
    EXTENDINGBRIDGENWWIDE8OUT = 507
    EXTENDINGBRIDGENWWIDE8 = 508
    EXTENDINGBRIDGENEWIDE10OUT = 509
    EXTENDINGBRIDGENEWIDE10 = 510
    EXTENDINGBRIDGENWWIDE10OUT = 511
    EXTENDINGBRIDGENWWIDE10 = 512
    EXTENDINGBRIDGENEWIDE12OUT = 513
    EXTENDINGBRIDGENEWIDE12 = 514
    EXTENDINGBRIDGENWWIDE12OUT = 515
    EXTENDINGBRIDGENWWIDE12 = 516
    COLLAPSIBLEROCKTOWERDEBRISRAMPRIGHT = 517
    COLLAPSIBLEROCKTOWERDEBRISRAMPLEFT = 518
    XELNAGA_CAVERNS_DOORE = 519
    XELNAGA_CAVERNS_DOOREOPENED = 520
    XELNAGA_CAVERNS_DOORN = 521
    XELNAGA_CAVERNS_DOORNE = 522
    XELNAGA_CAVERNS_DOORNEOPENED = 523
    XELNAGA_CAVERNS_DOORNOPENED = 524
    XELNAGA_CAVERNS_DOORNW = 525
    XELNAGA_CAVERNS_DOORNWOPENED = 526
    XELNAGA_CAVERNS_DOORS = 527
    XELNAGA_CAVERNS_DOORSE = 528
    XELNAGA_CAVERNS_DOORSEOPENED = 529
    XELNAGA_CAVERNS_DOORSOPENED = 530
    XELNAGA_CAVERNS_DOORSW = 531
    XELNAGA_CAVERNS_DOORSWOPENED = 532
    XELNAGA_CAVERNS_DOORW = 533
    XELNAGA_CAVERNS_DOORWOPENED = 534
    XELNAGA_CAVERNS_FLOATING_BRIDGENE8OUT = 535
    XELNAGA_CAVERNS_FLOATING_BRIDGENE8 = 536
    XELNAGA_CAVERNS_FLOATING_BRIDGENW8OUT = 537
    XELNAGA_CAVERNS_FLOATING_BRIDGENW8 = 538
    XELNAGA_CAVERNS_FLOATING_BRIDGENE10OUT = 539
    XELNAGA_CAVERNS_FLOATING_BRIDGENE10 = 540
    XELNAGA_CAVERNS_FLOATING_BRIDGENW10OUT = 541
    XELNAGA_CAVERNS_FLOATING_BRIDGENW10 = 542
    XELNAGA_CAVERNS_FLOATING_BRIDGENE12OUT = 543
    XELNAGA_CAVERNS_FLOATING_BRIDGENE12 = 544
    XELNAGA_CAVERNS_FLOATING_BRIDGENW12OUT = 545
    XELNAGA_CAVERNS_FLOATING_BRIDGENW12 = 546
    XELNAGA_CAVERNS_FLOATING_BRIDGEH8OUT = 547
    XELNAGA_CAVERNS_FLOATING_BRIDGEH8 = 548
    XELNAGA_CAVERNS_FLOATING_BRIDGEV8OUT = 549
    XELNAGA_CAVERNS_FLOATING_BRIDGEV8 = 550
    XELNAGA_CAVERNS_FLOATING_BRIDGEH10OUT = 551
    XELNAGA_CAVERNS_FLOATING_BRIDGEH10 = 552
    XELNAGA_CAVERNS_FLOATING_BRIDGEV10OUT = 553
    XELNAGA_CAVERNS_FLOATING_BRIDGEV10 = 554
    XELNAGA_CAVERNS_FLOATING_BRIDGEH12OUT = 555
    XELNAGA_CAVERNS_FLOATING_BRIDGEH12 = 556
    XELNAGA_CAVERNS_FLOATING_BRIDGEV12OUT = 557
    XELNAGA_CAVERNS_FLOATING_BRIDGEV12 = 558
    COLLAPSIBLETERRANTOWERPUSHUNITRAMPLEFT = 559
    COLLAPSIBLETERRANTOWERPUSHUNITRAMPRIGHT = 560
    COLLAPSIBLEROCKTOWERPUSHUNIT = 561
    COLLAPSIBLETERRANTOWERPUSHUNIT = 562
    COLLAPSIBLEROCKTOWERPUSHUNITRAMPRIGHT = 563
    COLLAPSIBLEROCKTOWERPUSHUNITRAMPLEFT = 564
    DIGESTERCREEPSPRAYTARGETUNIT = 565
    DIGESTERCREEPSPRAYUNIT = 566
    NYDUSCANALATTACKERWEAPON = 567
    VIPERCONSUMESTRUCTUREWEAPON = 568
    RESOURCEBLOCKER = 569
    TEMPESTWEAPON = 570
    YOINKMISSILE = 571
    YOINKVIKINGAIRMISSILE = 572
    YOINKVIKINGGROUNDMISSILE = 573
    YOINKSIEGETANKMISSILE = 574
    WARHOUNDWEAPON = 575
    EYESTALKWEAPON = 576
    WIDOWMINEWEAPON = 577
    WIDOWMINEAIRWEAPON = 578
    MOTHERSHIPCOREWEAPONWEAPON = 579
    TORNADOMISSILEWEAPON = 580
    TORNADOMISSILEDUMMYWEAPON = 581
    TALONSMISSILEWEAPON = 582
    CREEPTUMORMISSILE = 583
    LOCUSTMPEGGAMISSILEWEAPON = 584
    LOCUSTMPEGGBMISSILEWEAPON = 585
    LOCUSTMPWEAPON = 586
    REPULSORCANNONWEAPON = 587
    COLLAPSIBLEROCKTOWERDIAGONAL = 588
    COLLAPSIBLETERRANTOWERDIAGONAL = 589
    COLLAPSIBLETERRANTOWERRAMPLEFT = 590
    COLLAPSIBLETERRANTOWERRAMPRIGHT = 591
    ICE2X2NONCONJOINED = 592
    ICEPROTOSSCRATES = 593
    PROTOSSCRATES = 594
    TOWERMINE = 595
    PICKUPPALLETGAS = 596
    PICKUPPALLETMINERALS = 597
    PICKUPSCRAPSALVAGE1X1 = 598
    PICKUPSCRAPSALVAGE2X2 = 599
    PICKUPSCRAPSALVAGE3X3 = 600
    ROUGHTERRAIN = 601
    UNBUILDABLEBRICKSSMALLUNIT = 602
    UNBUILDABLEPLATESSMALLUNIT = 603
    UNBUILDABLEPLATESUNIT = 604
    UNBUILDABLEROCKSSMALLUNIT = 605
    XELNAGAHEALINGSHRINE = 606
    INVISIBLETARGETDUMMY = 607
    PROTOSSVESPENEGEYSER = 608
    COLLAPSIBLEROCKTOWER = 609
    COLLAPSIBLETERRANTOWER = 610
    THORNLIZARD = 611
    CLEANINGBOT = 612
    DESTRUCTIBLEROCK6X6WEAK = 613
    PROTOSSSNAKESEGMENTDEMO = 614
    PHYSICSCAPSULE = 615
    PHYSICSCUBE = 616
    PHYSICSCYLINDER = 617
    PHYSICSKNOT = 618
    PHYSICSL = 619
    PHYSICSPRIMITIVES = 620
    PHYSICSSPHERE = 621
    PHYSICSSTAR = 622
    CREEPBLOCKER4X4 = 623
    DESTRUCTIBLECITYDEBRIS2X4VERTICAL = 624
    DESTRUCTIBLECITYDEBRIS2X4HORIZONTAL = 625
    DESTRUCTIBLECITYDEBRIS2X6VERTICAL = 626
    DESTRUCTIBLECITYDEBRIS2X6HORIZONTAL = 627
    DESTRUCTIBLECITYDEBRIS4X4 = 628
    DESTRUCTIBLECITYDEBRIS6X6 = 629
    DESTRUCTIBLECITYDEBRISHUGEDIAGONALBLUR = 630
    DESTRUCTIBLECITYDEBRISHUGEDIAGONALULBR = 631
    TESTZERG = 632
    PATHINGBLOCKERRADIUS1 = 633
    DESTRUCTIBLEROCKEX12X4VERTICAL = 634
    DESTRUCTIBLEROCKEX12X4HORIZONTAL = 635
    DESTRUCTIBLEROCKEX12X6VERTICAL = 636
    DESTRUCTIBLEROCKEX12X6HORIZONTAL = 637
    DESTRUCTIBLEROCKEX14X4 = 638
    DESTRUCTIBLEROCKEX16X6 = 639
    DESTRUCTIBLEROCKEX1DIAGONALHUGEULBR = 640
    DESTRUCTIBLEROCKEX1DIAGONALHUGEBLUR = 641
    DESTRUCTIBLEROCKEX1VERTICALHUGE = 642
    DESTRUCTIBLEROCKEX1HORIZONTALHUGE = 643
    DESTRUCTIBLEICE2X4VERTICAL = 644
    DESTRUCTIBLEICE2X4HORIZONTAL = 645
    DESTRUCTIBLEICE2X6VERTICAL = 646
    DESTRUCTIBLEICE2X6HORIZONTAL = 647
    DESTRUCTIBLEICE4X4 = 648
    DESTRUCTIBLEICE6X6 = 649
    DESTRUCTIBLEICEDIAGONALHUGEULBR = 650
    DESTRUCTIBLEICEDIAGONALHUGEBLUR = 651
    DESTRUCTIBLEICEVERTICALHUGE = 652
    DESTRUCTIBLEICEHORIZONTALHUGE = 653
    DESERTPLANETSEARCHLIGHT = 654
    DESERTPLANETSTREETLIGHT = 655
    UNBUILDABLEBRICKSUNIT = 656
    UNBUILDABLEROCKSUNIT = 657
    ZERUSDESTRUCTIBLEARCH = 658
    ARTOSILOPE = 659
    ANTEPLOTT = 660
    LABBOT = 661
    CRABEETLE = 662
    COLLAPSIBLEROCKTOWERRAMPRIGHT = 663
    COLLAPSIBLEROCKTOWERRAMPLEFT = 664
    LABMINERALFIELD = 665
    LABMINERALFIELD750 = 666
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT8OUT = 667
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT8 = 668
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT8OUT = 669
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT8 = 670
    TARSONIS_DOORN = 671
    TARSONIS_DOORNLOWERED = 672
    TARSONIS_DOORNE = 673
    TARSONIS_DOORNELOWERED = 674
    TARSONIS_DOORE = 675
    TARSONIS_DOORELOWERED = 676
    TARSONIS_DOORNW = 677
    TARSONIS_DOORNWLOWERED = 678
    COMPOUNDMANSION_DOORN = 679
    COMPOUNDMANSION_DOORNLOWERED = 680
    COMPOUNDMANSION_DOORNE = 681
    COMPOUNDMANSION_DOORNELOWERED = 682
    COMPOUNDMANSION_DOORE = 683
    COMPOUNDMANSION_DOORELOWERED = 684
    COMPOUNDMANSION_DOORNW = 685
    COMPOUNDMANSION_DOORNWLOWERED = 686
    RAVAGERCOCOON = 687
    RAVAGER = 688
    LIBERATOR = 689
    RAVAGERBURROWED = 690
    THORAP = 691
    CYCLONE = 692
    LOCUSTMPFLYING = 693
    DISRUPTOR = 694
    AIURLIGHTBRIDGENE8OUT = 695
    AIURLIGHTBRIDGENE8 = 696
    AIURLIGHTBRIDGENE10OUT = 697
    AIURLIGHTBRIDGENE10 = 698
    AIURLIGHTBRIDGENE12OUT = 699
    AIURLIGHTBRIDGENE12 = 700
    AIURLIGHTBRIDGENW8OUT = 701
    AIURLIGHTBRIDGENW8 = 702
    AIURLIGHTBRIDGENW10OUT = 703
    AIURLIGHTBRIDGENW10 = 704
    AIURLIGHTBRIDGENW12OUT = 705
    AIURLIGHTBRIDGENW12 = 706
    AIURTEMPLEBRIDGENE8OUT = 707
    AIURTEMPLEBRIDGENE10OUT = 708
    AIURTEMPLEBRIDGENE12OUT = 709
    AIURTEMPLEBRIDGENW8OUT = 710
    AIURTEMPLEBRIDGENW10OUT = 711
    AIURTEMPLEBRIDGENW12OUT = 712
    SHAKURASLIGHTBRIDGENE8OUT = 713
    SHAKURASLIGHTBRIDGENE8 = 714
    SHAKURASLIGHTBRIDGENE10OUT = 715
    SHAKURASLIGHTBRIDGENE10 = 716
    SHAKURASLIGHTBRIDGENE12OUT = 717
    SHAKURASLIGHTBRIDGENE12 = 718
    SHAKURASLIGHTBRIDGENW8OUT = 719
    SHAKURASLIGHTBRIDGENW8 = 720
    SHAKURASLIGHTBRIDGENW10OUT = 721
    SHAKURASLIGHTBRIDGENW10 = 722
    SHAKURASLIGHTBRIDGENW12OUT = 723
    SHAKURASLIGHTBRIDGENW12 = 724
    VOIDMPIMMORTALREVIVECORPSE = 725
    GUARDIANCOCOONMP = 726
    GUARDIANMP = 727
    DEVOURERCOCOONMP = 728
    DEVOURERMP = 729
    DEFILERMPBURROWED = 730
    DEFILERMP = 731
    ORACLESTASISTRAP = 732
    DISRUPTORPHASED = 733
    LIBERATORAG = 734
    AIURLIGHTBRIDGEABANDONEDNE8OUT = 735
    AIURLIGHTBRIDGEABANDONEDNE8 = 736
    AIURLIGHTBRIDGEABANDONEDNE10OUT = 737
    AIURLIGHTBRIDGEABANDONEDNE10 = 738
    AIURLIGHTBRIDGEABANDONEDNE12OUT = 739
    AIURLIGHTBRIDGEABANDONEDNE12 = 740
    AIURLIGHTBRIDGEABANDONEDNW8OUT = 741
    AIURLIGHTBRIDGEABANDONEDNW8 = 742
    AIURLIGHTBRIDGEABANDONEDNW10OUT = 743
    AIURLIGHTBRIDGEABANDONEDNW10 = 744
    AIURLIGHTBRIDGEABANDONEDNW12OUT = 745
    AIURLIGHTBRIDGEABANDONEDNW12 = 746
    COLLAPSIBLEPURIFIERTOWERDEBRIS = 747
    PORTCITY_BRIDGE_UNITNE8OUT = 748
    PORTCITY_BRIDGE_UNITNE8 = 749
    PORTCITY_BRIDGE_UNITSE8OUT = 750
    PORTCITY_BRIDGE_UNITSE8 = 751
    PORTCITY_BRIDGE_UNITNW8OUT = 752
    PORTCITY_BRIDGE_UNITNW8 = 753
    PORTCITY_BRIDGE_UNITSW8OUT = 754
    PORTCITY_BRIDGE_UNITSW8 = 755
    PORTCITY_BRIDGE_UNITNE10OUT = 756
    PORTCITY_BRIDGE_UNITNE10 = 757
    PORTCITY_BRIDGE_UNITSE10OUT = 758
    PORTCITY_BRIDGE_UNITSE10 = 759
    PORTCITY_BRIDGE_UNITNW10OUT = 760
    PORTCITY_BRIDGE_UNITNW10 = 761
    PORTCITY_BRIDGE_UNITSW10OUT = 762
    PORTCITY_BRIDGE_UNITSW10 = 763
    PORTCITY_BRIDGE_UNITNE12OUT = 764
    PORTCITY_BRIDGE_UNITNE12 = 765
    PORTCITY_BRIDGE_UNITSE12OUT = 766
    PORTCITY_BRIDGE_UNITSE12 = 767
    PORTCITY_BRIDGE_UNITNW12OUT = 768
    PORTCITY_BRIDGE_UNITNW12 = 769
    PORTCITY_BRIDGE_UNITSW12OUT = 770
    PORTCITY_BRIDGE_UNITSW12 = 771
    PORTCITY_BRIDGE_UNITN8OUT = 772
    PORTCITY_BRIDGE_UNITN8 = 773
    PORTCITY_BRIDGE_UNITS8OUT = 774
    PORTCITY_BRIDGE_UNITS8 = 775
    PORTCITY_BRIDGE_UNITE8OUT = 776
    PORTCITY_BRIDGE_UNITE8 = 777
    PORTCITY_BRIDGE_UNITW8OUT = 778
    PORTCITY_BRIDGE_UNITW8 = 779
    PORTCITY_BRIDGE_UNITN10OUT = 780
    PORTCITY_BRIDGE_UNITN10 = 781
    PORTCITY_BRIDGE_UNITS10OUT = 782
    PORTCITY_BRIDGE_UNITS10 = 783
    PORTCITY_BRIDGE_UNITE10OUT = 784
    PORTCITY_BRIDGE_UNITE10 = 785
    PORTCITY_BRIDGE_UNITW10OUT = 786
    PORTCITY_BRIDGE_UNITW10 = 787
    PORTCITY_BRIDGE_UNITN12OUT = 788
    PORTCITY_BRIDGE_UNITN12 = 789
    PORTCITY_BRIDGE_UNITS12OUT = 790
    PORTCITY_BRIDGE_UNITS12 = 791
    PORTCITY_BRIDGE_UNITE12OUT = 792
    PORTCITY_BRIDGE_UNITE12 = 793
    PORTCITY_BRIDGE_UNITW12OUT = 794
    PORTCITY_BRIDGE_UNITW12 = 795
    PURIFIERRICHMINERALFIELD = 796
    PURIFIERRICHMINERALFIELD750 = 797
    COLLAPSIBLEPURIFIERTOWERPUSHUNIT = 798
    LOCUSTMPPRECURSOR = 799
    RELEASEINTERCEPTORSBEACON = 800
    ADEPTPHASESHIFT = 801
    RAVAGERCORROSIVEBILEMISSILE = 802
    HYDRALISKIMPALEMISSILE = 803
    CYCLONEMISSILELARGEAIR = 804
    CYCLONEMISSILE = 805
    CYCLONEMISSILELARGE = 806
    THORAALANCE = 807
    ORACLEWEAPON = 808
    TEMPESTWEAPONGROUND = 809
    RAVAGERWEAPONMISSILE = 810
    SCOUTMPAIRWEAPONLEFT = 811
    SCOUTMPAIRWEAPONRIGHT = 812
    ARBITERMPWEAPONMISSILE = 813
    GUARDIANMPWEAPON = 814
    DEVOURERMPWEAPONMISSILE = 815
    DEFILERMPDARKSWARMWEAPON = 816
    QUEENMPENSNAREMISSILE = 817
    QUEENMPSPAWNBROODLINGSMISSILE = 818
    LIGHTNINGBOMBWEAPON = 819
    HERCPLACEMENT = 820
    GRAPPLEWEAPON = 821
    CAUSTICSPRAYMISSILE = 822
    PARASITICBOMBMISSILE = 823
    PARASITICBOMBDUMMY = 824
    ADEPTWEAPON = 825
    ADEPTUPGRADEWEAPON = 826
    LIBERATORMISSILE = 827
    LIBERATORDAMAGEMISSILE = 828
    LIBERATORAGMISSILE = 829
    KD8CHARGE = 830
    KD8CHARGEWEAPON = 831
    SLAYNELEMENTALGRABWEAPON = 832
    SLAYNELEMENTALGRABAIRUNIT = 833
    SLAYNELEMENTALGRABGROUNDUNIT = 834
    SLAYNELEMENTALWEAPON = 835
    DESTRUCTIBLEEXPEDITIONGATE6X6 = 836
    DESTRUCTIBLEZERGINFESTATION3X3 = 837
    HERC = 838
    MOOPY = 839
    REPLICANT = 840
    SEEKERMISSILE = 841
    AIURTEMPLEBRIDGEDESTRUCTIBLENE8OUT = 842
    AIURTEMPLEBRIDGEDESTRUCTIBLENE10OUT = 843
    AIURTEMPLEBRIDGEDESTRUCTIBLENE12OUT = 844
    AIURTEMPLEBRIDGEDESTRUCTIBLENW8OUT = 845
    AIURTEMPLEBRIDGEDESTRUCTIBLENW10OUT = 846
    AIURTEMPLEBRIDGEDESTRUCTIBLENW12OUT = 847
    AIURTEMPLEBRIDGEDESTRUCTIBLESW8OUT = 848
    AIURTEMPLEBRIDGEDESTRUCTIBLESW10OUT = 849
    AIURTEMPLEBRIDGEDESTRUCTIBLESW12OUT = 850
    AIURTEMPLEBRIDGEDESTRUCTIBLESE8OUT = 851
    AIURTEMPLEBRIDGEDESTRUCTIBLESE10OUT = 852
    AIURTEMPLEBRIDGEDESTRUCTIBLESE12OUT = 853
    FLYOVERUNIT = 854
    CORSAIRMP = 855
    SCOUTMP = 856
    ARBITERMP = 857
    SCOURGEMP = 858
    DEFILERMPPLAGUEWEAPON = 859
    QUEENMP = 860
    XELNAGADESTRUCTIBLERAMPBLOCKER6S = 861
    XELNAGADESTRUCTIBLERAMPBLOCKER6SE = 862
    XELNAGADESTRUCTIBLERAMPBLOCKER6E = 863
    XELNAGADESTRUCTIBLERAMPBLOCKER6NE = 864
    XELNAGADESTRUCTIBLERAMPBLOCKER6N = 865
    XELNAGADESTRUCTIBLERAMPBLOCKER6NW = 866
    XELNAGADESTRUCTIBLERAMPBLOCKER6W = 867
    XELNAGADESTRUCTIBLERAMPBLOCKER6SW = 868
    XELNAGADESTRUCTIBLERAMPBLOCKER8S = 869
    XELNAGADESTRUCTIBLERAMPBLOCKER8SE = 870
    XELNAGADESTRUCTIBLERAMPBLOCKER8E = 871
    XELNAGADESTRUCTIBLERAMPBLOCKER8NE = 872
    XELNAGADESTRUCTIBLERAMPBLOCKER8N = 873
    XELNAGADESTRUCTIBLERAMPBLOCKER8NW = 874
    XELNAGADESTRUCTIBLERAMPBLOCKER8W = 875
    XELNAGADESTRUCTIBLERAMPBLOCKER8SW = 876
    REPTILECRATE = 877
    SLAYNSWARMHOSTSPAWNFLYER = 878
    SLAYNELEMENTAL = 879
    PURIFIERVESPENEGEYSER = 880
    SHAKURASVESPENEGEYSER = 881
    COLLAPSIBLEPURIFIERTOWERDIAGONAL = 882
    CREEPONLYBLOCKER4X4 = 883
    PURIFIERMINERALFIELD = 884
    PURIFIERMINERALFIELD750 = 885
    BATTLESTATIONMINERALFIELD = 886
    BATTLESTATIONMINERALFIELD750 = 887
    BEACON_NOVA = 888
    BEACON_NOVASMALL = 889
    URSULA = 890
    ELSECARO_COLONIST_HUT = 891
    TRANSPORTOVERLORDCOCOON = 892
    OVERLORDTRANSPORT = 893
    PYLONOVERCHARGED = 894
    BYPASSARMORDRONE = 895
    ADEPTPIERCINGWEAPON = 896
    CORROSIVEPARASITEWEAPON = 897
    INFESTEDTERRAN = 898
    MERCCOMPOUND = 899
    SUPPLYDEPOTDROP = 900
    LURKERDEN = 901
    D8CHARGE = 902
    THORWRECKAGE = 903
    GOLIATH = 904
    TECHREACTOR = 905
    SS_POWERUPBOMB = 906
    SS_POWERUPHEALTH = 907
    SS_POWERUPSIDEMISSILES = 908
    SS_POWERUPSTRONGERMISSILES = 909
    LURKEREGG = 910
    LURKER = 911
    LURKERBURROWED = 912
    ARCHIVESEALED = 913
    INFESTEDCIVILIAN = 914
    FLAMINGBETTY = 915
    INFESTEDCIVILIANBURROWED = 916
    SELENDISINTERCEPTOR = 917
    SIEGEBREAKERSIEGED = 918
    SIEGEBREAKER = 919
    PERDITIONTURRETUNDERGROUND = 920
    PERDITIONTURRET = 921
    SENTRYGUNUNDERGROUND = 922
    SENTRYGUN = 923
    WARPIG = 924
    DEVILDOG = 925
    SPARTANCOMPANY = 926
    HAMMERSECURITY = 927
    HELSANGELFIGHTER = 928
    DUSKWING = 929
    DUKESREVENGE = 930
    ODINWRECKAGE = 931
    HERONUKE = 932
    KERRIGANCHARBURROWED = 933
    KERRIGANCHAR = 934
    SPIDERMINEBURROWED = 935
    SPIDERMINE = 936
    ZERATUL = 937
    URUN = 938
    MOHANDAR = 939
    SELENDIS = 940
    SCOUT = 941
    OMEGALISKBURROWED = 942
    OMEGALISK = 943
    INFESTEDABOMINATIONBURROWED = 944
    INFESTEDABOMINATION = 945
    HUNTERKILLERBURROWED = 946
    HUNTERKILLER = 947
    INFESTEDTERRANCAMPAIGNBURROWED = 948
    INFESTEDTERRANCAMPAIGN = 949
    CHECKSTATION = 950
    CHECKSTATIONDIAGONALBLUR = 951
    CHECKSTATIONDIAGONALULBR = 952
    CHECKSTATIONVERTICAL = 953
    CHECKSTATIONOPENED = 954
    CHECKSTATIONDIAGONALBLUROPENED = 955
    CHECKSTATIONDIAGONALULBROPENED = 956
    CHECKSTATIONVERTICALOPENED = 957
    BARRACKSTECHREACTOR = 958
    FACTORYTECHREACTOR = 959
    STARPORTTECHREACTOR = 960
    SPECTRENUKE = 961
    COLONISTSHIPFLYING = 962
    COLONISTSHIP = 963
    BIODOMECOMMANDFLYING = 964
    BIODOMECOMMAND = 965
    HERCULESLANDERFLYING = 966
    HERCULESLANDER = 967
    ZHAKULDASLIGHTBRIDGEOFF = 968
    ZHAKULDASLIGHTBRIDGE = 969
    ZHAKULDASLIBRARYUNITBURROWED = 970
    ZHAKULDASLIBRARYUNIT = 971
    XELNAGATEMPLEDOORBURROWED = 972
    XELNAGATEMPLEDOOR = 973
    XELNAGATEMPLEDOORURDLBURROWED = 974
    XELNAGATEMPLEDOORURDL = 975
    HELSANGELASSAULT = 976
    AUTOMATEDREFINERY = 977
    BATTLECRUISERHELIOSMORPH = 978
    HEALINGPOTIONTESTINSTANT = 979
    SPACEPLATFORMCLIFFDOOROPEN0 = 980
    SPACEPLATFORMCLIFFDOOR0 = 981
    SPACEPLATFORMCLIFFDOOROPEN1 = 982
    SPACEPLATFORMCLIFFDOOR1 = 983
    DESTRUCTIBLEGATEDIAGONALBLURLOWERED = 984
    DESTRUCTIBLEGATEDIAGONALULBRLOWERED = 985
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALBFLOWERED = 986
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALLOWERED = 987
    DESTRUCTIBLEGATESTRAIGHTVERTICALLFLOWERED = 988
    DESTRUCTIBLEGATESTRAIGHTVERTICALLOWERED = 989
    DESTRUCTIBLEGATEDIAGONALBLUR = 990
    DESTRUCTIBLEGATEDIAGONALULBR = 991
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALBF = 992
    DESTRUCTIBLEGATESTRAIGHTHORIZONTAL = 993
    DESTRUCTIBLEGATESTRAIGHTVERTICALLF = 994
    DESTRUCTIBLEGATESTRAIGHTVERTICAL = 995
    METALGATEDIAGONALBLURLOWERED = 996
    METALGATEDIAGONALULBRLOWERED = 997
    METALGATESTRAIGHTHORIZONTALBFLOWERED = 998
    METALGATESTRAIGHTHORIZONTALLOWERED = 999
    METALGATESTRAIGHTVERTICALLFLOWERED = 1000
    METALGATESTRAIGHTVERTICALLOWERED = 1001
    METALGATEDIAGONALBLUR = 1002
    METALGATEDIAGONALULBR = 1003
    METALGATESTRAIGHTHORIZONTALBF = 1004
    METALGATESTRAIGHTHORIZONTAL = 1005
    METALGATESTRAIGHTVERTICALLF = 1006
    METALGATESTRAIGHTVERTICAL = 1007
    SECURITYGATEDIAGONALBLURLOWERED = 1008
    SECURITYGATEDIAGONALULBRLOWERED = 1009
    SECURITYGATESTRAIGHTHORIZONTALBFLOWERED = 1010
    SECURITYGATESTRAIGHTHORIZONTALLOWERED = 1011
    SECURITYGATESTRAIGHTVERTICALLFLOWERED = 1012
    SECURITYGATESTRAIGHTVERTICALLOWERED = 1013
    SECURITYGATEDIAGONALBLUR = 1014
    SECURITYGATEDIAGONALULBR = 1015
    SECURITYGATESTRAIGHTHORIZONTALBF = 1016
    SECURITYGATESTRAIGHTHORIZONTAL = 1017
    SECURITYGATESTRAIGHTVERTICALLF = 1018
    SECURITYGATESTRAIGHTVERTICAL = 1019
    TERRAZINENODEDEADTERRAN = 1020
    TERRAZINENODEHAPPYPROTOSS = 1021
    ZHAKULDASLIGHTBRIDGEOFFTOPRIGHT = 1022
    ZHAKULDASLIGHTBRIDGETOPRIGHT = 1023
    BATTLECRUISERHELIOS = 1024
    NUKESILONOVA = 1025
    ODIN = 1026
    PYGALISKCOCOON = 1027
    DEVOURERTISSUEDOODAD = 1028
    SS_BATTLECRUISERMISSILELAUNCHER = 1029
    SS_TERRATRONMISSILESPINNERMISSILE = 1030
    SS_TERRATRONSAW = 1031
    SS_BATTLECRUISERHUNTERSEEKERMISSILE = 1032
    SS_LEVIATHANBOMB = 1033
    DEVOURERTISSUEMISSILE = 1034
    SS_INTERCEPTOR = 1035
    SS_LEVIATHANBOMBMISSILE = 1036
    SS_LEVIATHANSPAWNBOMBMISSILE = 1037
    SS_FIGHTERMISSILELEFT = 1038
    SS_FIGHTERMISSILERIGHT = 1039
    SS_INTERCEPTORSPAWNMISSILE = 1040
    SS_CARRIERBOSSMISSILE = 1041
    SS_LEVIATHANTENTACLETARGET = 1042
    SS_LEVIATHANTENTACLEL2MISSILE = 1043
    SS_LEVIATHANTENTACLER1MISSILE = 1044
    SS_LEVIATHANTENTACLER2MISSILE = 1045
    SS_LEVIATHANTENTACLEL1MISSILE = 1046
    SS_TERRATRONMISSILE = 1047
    SS_WRAITHMISSILE = 1048
    SS_SCOURGEMISSILE = 1049
    SS_CORRUPTORMISSILE = 1050
    SS_SWARMGUARDIANMISSILE = 1051
    SS_STRONGMISSILE1 = 1052
    SS_STRONGMISSILE2 = 1053
    SS_FIGHTERDRONEMISSILE = 1054
    SS_PHOENIXMISSILE = 1055
    SS_SCOUTMISSILE = 1056
    SS_INTERCEPTORMISSILE = 1057
    SS_SCIENCEVESSELMISSILE = 1058
    SS_BATTLECRUISERMISSILE = 1059
    D8CLUSTERBOMBWEAPON = 1060
    D8CLUSTERBOMB = 1061
    BROODLORDEGG = 1062
    BROODLORDEGGMISSILE = 1063
    CIVILIANWEAPON = 1064
    BATTLECRUISERHELIOSALMWEAPON = 1065
    BATTLECRUISERLOKILMWEAPON = 1066
    BATTLECRUISERHELIOSGLMWEAPON = 1067
    BIOSTASISMISSILE = 1068
    INFESTEDVENTBROODLORDEGG = 1069
    INFESTEDVENTCORRUPTOREGG = 1070
    TENTACLEAMISSILE = 1071
    TENTACLEBMISSILE = 1072
    TENTACLECMISSILE = 1073
    TENTACLEDMISSILE = 1074
    MUTALISKEGG = 1075
    INFESTEDVENTMUTALISKEGG = 1076
    MUTALISKEGGMISSILE = 1077
    INFESTEDVENTEGGMISSILE = 1078
    SPORECANNONFIREMISSILE = 1079
    EXPERIMENTALPLASMAGUNWEAPON = 1080
    BRUTALISKWEAPON = 1081
    LOKIHURRICANEMISSILELEFT = 1082
    LOKIHURRICANEMISSILERIGHT = 1083
    ODINAAWEAPON = 1084
    DUSKWINGWEAPON = 1085
    KERRIGANWEAPON = 1086
    ULTRASONICPULSEWEAPON = 1087
    KERRIGANCHARWEAPON = 1088
    DEVASTATORMISSILEWEAPON = 1089
    SWANNWEAPON = 1090
    HAMMERSECURITYLMWEAPON = 1091
    CONSUMEDNAFEEDBACKWEAPON = 1092
    URUNWEAPONLEFT = 1093
    URUNWEAPONRIGHT = 1094
    HAILSTORMMISSILESWEAPON = 1095
    COLONYINFESTATIONWEAPON = 1096
    VOIDSEEKERPHASEMINEBLASTWEAPON = 1097
    VOIDSEEKERPHASEMINEBLASTSECONDARYWEAPON = 1098
    TOSSGRENADEWEAPON = 1099
    TYCHUSGRENADEWEAPON = 1100
    VILESTREAMWEAPON = 1101
    WRAITHAIRWEAPONRIGHT = 1102
    WRAITHAIRWEAPONLEFT = 1103
    WRAITHGROUNDWEAPON = 1104
    WEAPONHYBRIDD = 1105
    KARASSWEAPON = 1106
    HYBRIDCPLASMAWEAPON = 1107
    WARBOTBMISSILE = 1108
    LOKIYAMATOWEAPON = 1109
    HYPERIONYAMATOSPECIALWEAPON = 1110
    HYPERIONLMWEAPON = 1111
    HYPERIONALMWEAPON = 1112
    VULTUREWEAPON = 1113
    SCOUTAIRWEAPONLEFT = 1114
    SCOUTAIRWEAPONRIGHT = 1115
    HUNTERKILLERWEAPON = 1116
    GOLIATHAWEAPON = 1117
    SPARTANCOMPANYAWEAPON = 1118
    LEVIATHANSCOURGEMISSILE = 1119
    BIOPLASMIDDISCHARGEWEAPON = 1120
    VOIDSEEKERWEAPON = 1121
    HELSANGELFIGHTERWEAPON = 1122
    DRBATTLECRUISERALMWEAPON = 1123
    DRBATTLECRUISERGLMWEAPON = 1124
    HURRICANEMISSILERIGHT = 1125
    HURRICANEMISSILELEFT = 1126
    HYBRIDSINGULARITYFEEDBACKWEAPON = 1127
    DOMINIONKILLTEAMLMWEAPON = 1128
    ITEMGRENADESWEAPON = 1129
    ITEMGRAVITYBOMBSWEAPON = 1130
    TESTHEROTHROWMISSILE = 1131
    TESTHERODEBUGMISSILEABILITY1WEAPON = 1132
    TESTHERODEBUGMISSILEABILITY2WEAPON = 1133
    SPECTRE = 1134
    VULTURE = 1135
    LOKI = 1136
    WRAITH = 1137
    DOMINIONKILLTEAM = 1138
    FIREBAT = 1139
    DIAMONDBACK = 1140
    G4CHARGEWEAPON = 1141
    SS_BLACKEDGEBORDER = 1142
    DEVOURERTISSUESAMPLETUBE = 1143
    MONOLITH = 1144
    OBELISK = 1145
    ARCHIVE = 1146
    ARTIFACTVAULT = 1147
    AVERNUSGATECONTROL = 1148
    GATECONTROLUNIT = 1149
    BLIMPADS = 1150
    BLOCKER6X6 = 1151
    BLOCKER8X8 = 1152
    BLOCKER16X16 = 1153
    CARGOTRUCKUNITFLATBED = 1154
    CARGOTRUCKUNITTRAILER = 1155
    BLIMP = 1156
    CASTANARWINDOWLARGEDIAGONALULBRUNIT = 1157
    BLOCKER4X4 = 1158
    HOMELARGE = 1159
    HOMESMALL = 1160
    ELEVATORBLOCKER = 1161
    QUESTIONMARK = 1162
    NYDUSWORMLAVADEATH = 1163
    SS_BACKGROUNDSPACELARGE = 1164
    SS_BACKGROUNDSPACETERRAN00 = 1165
    SS_BACKGROUNDSPACETERRAN02 = 1166
    SS_BACKGROUNDSPACEZERG00 = 1167
    SS_BACKGROUNDSPACEZERG02 = 1168
    SS_CARRIERBOSS = 1169
    SS_BATTLECRUISER = 1170
    SS_TERRATRONMISSILESPINNERLAUNCHER = 1171
    SS_TERRATRONMISSILESPINNER = 1172
    SS_TERRATRONBEAMTARGET = 1173
    SS_LIGHTNINGPROJECTORFACERIGHT = 1174
    SS_SCOURGE = 1175
    SS_CORRUPTOR = 1176
    SS_TERRATRONMISSILELAUNCHER = 1177
    SS_LIGHTNINGPROJECTORFACELEFT = 1178
    SS_WRAITH = 1179
    SS_SWARMGUARDIAN = 1180
    SS_SCOUT = 1181
    SS_LEVIATHAN = 1182
    SS_SCIENCEVESSEL = 1183
    SS_TERRATRON = 1184
    SECRETDOCUMENTS = 1185
    PREDATOR = 1186
    DEFILERBONESAMPLE = 1187
    DEVOURERTISSUESAMPLE = 1188
    PROTOSSPSIELEMENTS = 1189
    TASSADAR = 1190
    SCIENCEFACILITY = 1191
    INFESTEDCOCOON = 1192
    FUSIONREACTOR = 1193
    BUBBACOMMERCIAL = 1194
    XELNAGAPRISONHEIGHT2 = 1195
    XELNAGAPRISON = 1196
    XELNAGAPRISONNORTH = 1197
    XELNAGAPRISONNORTHHEIGHT2 = 1198
    ZERGDROPPODCREEP = 1199
    IPISTOLAD = 1200
    L800ETC_AD = 1201
    NUKENOODLESCOMMERCIAL = 1202
    PSIOPSCOMMERCIAL = 1203
    SHIPALARM = 1204
    SPACEPLATFORMDESTRUCTIBLEJUMBOBLOCKER = 1205
    SPACEPLATFORMDESTRUCTIBLELARGEBLOCKER = 1206
    SPACEPLATFORMDESTRUCTIBLEMEDIUMBLOCKER = 1207
    SPACEPLATFORMDESTRUCTIBLESMALLBLOCKER = 1208
    TALDARIMMOTHERSHIP = 1209
    PLASMATORPEDOESWEAPON = 1210
    PSIDISRUPTOR = 1211
    HIVEMINDEMULATOR = 1212
    RAYNOR01 = 1213
    SCIENCEVESSEL = 1214
    SCOURGE = 1215
    SPACEPLATFORMREACTORPATHINGBLOCKER = 1216
    TAURENOUTHOUSE = 1217
    TYCHUSEJECTMISSILE = 1218
    FEEDERLING = 1219
    ULAANSMOKEBRIDGE = 1220
    TALDARIMPRISONCRYSTAL = 1221
    SPACEDIABLO = 1222
    MURLOCMARINE = 1223
    XELNAGAPRISONCONSOLE = 1224
    TALDARIMPRISON = 1225
    ADJUTANTCAPSULE = 1226
    XELNAGAVAULT = 1227
    HOLDINGPEN = 1228
    SCRAPHUGE = 1229
    PRISONERCIVILIAN = 1230
    BIODOMEHALFBUILT = 1231
    BIODOME = 1232
    DESTRUCTIBLEKORHALFLAG = 1233
    DESTRUCTIBLEKORHALPODIUM = 1234
    DESTRUCTIBLEKORHALTREE = 1235
    DESTRUCTIBLEKORHALFOLIAGE = 1236
    DESTRUCTIBLESANDBAGS = 1237
    CASTANARWINDOWLARGEDIAGONALBLURUNIT = 1238
    CARGOTRUCKUNITBARRELS = 1239
    SPORECANNON = 1240
    STETMANN = 1241
    BRIDGEBLOCKER4X12 = 1242
    CIVILIANSHIPWRECKED = 1243
    SWANN = 1244
    DRAKKENLASERDRILL = 1245
    MINDSIPHONRETURNWEAPON = 1246
    KERRIGANEGG = 1247
    CHRYSALISEGG = 1248
    PRISONERSPECTRE = 1249
    PRISONZEALOT = 1250
    SCRAPSALVAGE1X1 = 1251
    SCRAPSALVAGE2X2 = 1252
    SCRAPSALVAGE3X3 = 1253
    RAYNORCOMMANDO = 1254
    OVERMIND = 1255
    OVERMINDREMAINS = 1256
    INFESTEDMERCHAVEN = 1257
    MONLYTHARTIFACTFORCEFIELD = 1258
    MONLYTHFORCEFIELDSTATUE = 1259
    VIROPHAGE = 1260
    PSISHOCKWEAPON = 1261
    TYCHUSCOMMANDO = 1262
    BRUTALISK = 1263
    PYGALISK = 1264
    VALHALLABASEDESTRUCTIBLEDOORDEAD = 1265
    VALHALLABASEDESTRUCTIBLEDOOR = 1266
    VOIDSEEKER = 1267
    MINDSIPHONWEAPON = 1268
    WARBOT = 1269
    PLATFORMCONNECTOR = 1270
    ARTANIS = 1271
    TERRAZINECANISTER = 1272
    HERCULES = 1273
    MERCENARYFORTRESS = 1274
    RAYNOR = 1275
    ARTIFACTPIECE1 = 1276
    ARTIFACTPIECE2 = 1277
    ARTIFACTPIECE4 = 1278
    ARTIFACTPIECE3 = 1279
    ARTIFACTPIECE5 = 1280
    RIPFIELDGENERATOR = 1281
    RIPFIELDGENERATORSMALL = 1282
    XELNAGAWORLDSHIPVAULT = 1283
    TYCHUSCHAINGUN = 1284
    ARTIFACT = 1285
    CELLBLOCKB = 1286
    GHOSTLASERLINES = 1287
    MAINCELLBLOCK = 1288
    KERRIGAN = 1289
    DATACORE = 1290
    SPECIALOPSDROPSHIP = 1291
    TOSH = 1292
    CASTANARULTRALISKSHACKLEDUNIT = 1293
    KARASS = 1294
    INVISIBLEPYLON = 1295
    MAAR = 1296
    HYBRIDDESTROYER = 1297
    HYBRIDREAVER = 1298
    HYBRID = 1299
    TERRAZINENODE = 1300
    TRANSPORTTRUCK = 1301
    WALLOFFIRE = 1302
    WEAPONHYBRIDC = 1303
    XELNAGATEMPLE = 1304
    EXPLODINGBARRELLARGE = 1305
    SUPERWARPGATE = 1306
    TERRAZINETANK = 1307
    XELNAGASHRINE = 1308
    SMCAMERABRIDGE = 1309
    SMMARSARABARTYCHUSCAMERAS = 1310
    SMHYPERIONBRIDGESTAGE1HANSONCAMERAS = 1311
    SMHYPERIONBRIDGESTAGE1HORNERCAMERAS = 1312
    SMHYPERIONBRIDGESTAGE1TYCHUSCAMERAS = 1313
    SMHYPERIONBRIDGESTAGE1TOSHCAMERAS = 1314
    SMHYPERIONARMORYSTAGE1SWANNCAMERAS = 1315
    SMHYPERIONCANTINATOSHCAMERAS = 1316
    SMHYPERIONCANTINATYCHUSCAMERAS = 1317
    SMHYPERIONCANTINAYBARRACAMERAS = 1318
    SMHYPERIONLABADJUTANTCAMERAS = 1319
    SMHYPERIONLABCOWINCAMERAS = 1320
    SMHYPERIONLABHANSONCAMERAS = 1321
    SMHYPERIONBRIDGETRAYNOR03BRIEFINGCAMERA = 1322
    SMTESTCAMERA = 1323
    SMCAMERATERRAN01 = 1324
    SMCAMERATERRAN02A = 1325
    SMCAMERATERRAN02B = 1326
    SMCAMERATERRAN03 = 1327
    SMCAMERATERRAN04 = 1328
    SMCAMERATERRAN04A = 1329
    SMCAMERATERRAN04B = 1330
    SMCAMERATERRAN05 = 1331
    SMCAMERATERRAN06A = 1332
    SMCAMERATERRAN06B = 1333
    SMCAMERATERRAN06C = 1334
    SMCAMERATERRAN07 = 1335
    SMCAMERATERRAN08 = 1336
    SMCAMERATERRAN09 = 1337
    SMCAMERATERRAN10 = 1338
    SMCAMERATERRAN11 = 1339
    SMCAMERATERRAN12 = 1340
    SMCAMERATERRAN13 = 1341
    SMCAMERATERRAN14 = 1342
    SMCAMERATERRAN15 = 1343
    SMCAMERATERRAN16 = 1344
    SMCAMERATERRAN17 = 1345
    SMCAMERATERRAN20 = 1346
    SMFIRSTOFFICER = 1347
    SMHYPERIONBRIDGEBRIEFINGLEFT = 1348
    SMHYPERIONBRIDGEBRIEFINGRIGHT = 1349
    SMHYPERIONMEDLABBRIEFING = 1350
    SMHYPERIONMEDLABBRIEFINGCENTER = 1351
    SMHYPERIONMEDLABBRIEFINGLEFT = 1352
    SMHYPERIONMEDLABBRIEFINGRIGHT = 1353
    SMTOSHSHUTTLESET = 1354
    SMKERRIGANPHOTO = 1355
    SMTOSHSHUTTLESET2 = 1356
    SMMARSARABARJUKEBOXHS = 1357
    SMMARSARABARKERRIGANPHOTOHS = 1358
    SMVALERIANFLAGSHIPCORRIDORSSET = 1359
    SMVALERIANFLAGSHIPCORRIDORSSET2 = 1360
    SMVALERIANFLAGSHIPCORRIDORSSET3 = 1361
    SMVALERIANFLAGSHIPCORRIDORSSET4 = 1362
    SMVALERIANOBSERVATORYSET = 1363
    SMVALERIANOBSERVATORYSET2 = 1364
    SMVALERIANOBSERVATORYSET3 = 1365
    SMVALERIANOBSERVATORYPAINTINGHS = 1366
    SMCHARBATTLEZONEFLAG = 1367
    SMUNNSET = 1368
    SMTERRANREADYROOMSET = 1369
    SMCHARBATTLEZONESET = 1370
    SMCHARBATTLEZONESET2 = 1371
    SMCHARBATTLEZONESET3 = 1372
    SMCHARBATTLEZONESET4 = 1373
    SMCHARBATTLEZONESET5 = 1374
    SMCHARBATTLEZONEARTIFACTHS = 1375
    SMCHARBATTLEZONERADIOHS = 1376
    SMCHARBATTLEZONEDROPSHIPHS = 1377
    SMCHARBATTLEZONEBRIEFCASEHS = 1378
    SMCHARBATTLEZONEBRIEFINGSET = 1379
    SMCHARBATTLEZONEBRIEFINGSET2 = 1380
    SMCHARBATTLEZONEBRIEFINGSETLEFT = 1381
    SMCHARBATTLEZONEBRIEFINGSETRIGHT = 1382
    SMMARSARABARBADGEHS = 1383
    SMHYPERIONCANTINABADGEHS = 1384
    SMHYPERIONCANTINAPOSTER1HS = 1385
    SMHYPERIONCANTINAPOSTER2HS = 1386
    SMHYPERIONCANTINAPOSTER3HS = 1387
    SMHYPERIONCANTINAPOSTER4HS = 1388
    SMHYPERIONCANTINAPOSTER5HS = 1389
    SMFLY = 1390
    SMBRIDGEWINDOWSPACE = 1391
    SMBRIDGEPLANETSPACE = 1392
    SMBRIDGEPLANETSPACEASTEROIDS = 1393
    SMBRIDGEPLANETAGRIA = 1394
    SMBRIDGEPLANETAIUR = 1395
    SMBRIDGEPLANETAVERNUS = 1396
    SMBRIDGEPLANETBELSHIR = 1397
    SMBRIDGEPLANETCASTANAR = 1398
    SMBRIDGEPLANETCHAR = 1399
    SMBRIDGEPLANETHAVEN = 1400
    SMBRIDGEPLANETKORHAL = 1401
    SMBRIDGEPLANETMEINHOFF = 1402
    SMBRIDGEPLANETMONLYTH = 1403
    SMBRIDGEPLANETNEWFOLSOM = 1404
    SMBRIDGEPLANETPORTZION = 1405
    SMBRIDGEPLANETREDSTONE = 1406
    SMBRIDGEPLANETSHAKURAS = 1407
    SMBRIDGEPLANETTARSONIS = 1408
    SMBRIDGEPLANETTYPHON = 1409
    SMBRIDGEPLANETTYRADOR = 1410
    SMBRIDGEPLANETULAAN = 1411
    SMBRIDGEPLANETULNAR = 1412
    SMBRIDGEPLANETVALHALLA = 1413
    SMBRIDGEPLANETXIL = 1414
    SMBRIDGEPLANETZHAKULDAS = 1415
    SMMARSARAPLANET = 1416
    SMNOVA = 1417
    SMHAVENPLANET = 1418
    SMHYPERIONBRIDGEBRIEFING = 1419
    SMHYPERIONBRIDGEBRIEFINGCENTER = 1420
    SMCHARBATTLEFIELDENDPROPS = 1421
    SMCHARBATTLEZONETURRET = 1422
    SMTERRAN01FX = 1423
    SMTERRAN03FX = 1424
    SMTERRAN05FX = 1425
    SMTERRAN05FXMUTALISKS = 1426
    SMTERRAN05PROPS = 1427
    SMTERRAN06AFX = 1428
    SMTERRAN06BFX = 1429
    SMTERRAN06CFX = 1430
    SMTERRAN12FX = 1431
    SMTERRAN14FX = 1432
    SMTERRAN15FX = 1433
    SMTERRAN06APROPS = 1434
    SMTERRAN06BPROPS = 1435
    SMTERRAN07PROPS = 1436
    SMTERRAN07FX = 1437
    SMTERRAN08PROPS = 1438
    SMTERRAN09FX = 1439
    SMTERRAN09PROPS = 1440
    SMTERRAN11FX = 1441
    SMTERRAN11FXMISSILES = 1442
    SMTERRAN11FXEXPLOSIONS = 1443
    SMTERRAN11FXBLOOD = 1444
    SMTERRAN11FXDEBRIS = 1445
    SMTERRAN11FXDEBRIS1 = 1446
    SMTERRAN11FXDEBRIS2 = 1447
    SMTERRAN11PROPS = 1448
    SMTERRAN11PROPSBURROWROCKS = 1449
    SMTERRAN11PROPSRIFLESHELLS = 1450
    SMTERRAN12PROPS = 1451
    SMTERRAN13PROPS = 1452
    SMTERRAN14PROPS = 1453
    SMTERRAN15PROPS = 1454
    SMTERRAN16FX = 1455
    SMTERRAN16FXFLAK = 1456
    SMTERRAN17PROPS = 1457
    SMTERRAN17FX = 1458
    SMMARSARABARPROPS = 1459
    SMHYPERIONCORRIDORPROPS = 1460
    ZERATULCRYSTALCHARGE = 1461
    SMRAYNORHANDS = 1462
    SMPRESSROOMPROPS = 1463
    SMRAYNORGUN = 1464
    SMMARINERIFLE = 1465
    SMTOSHKNIFE = 1466
    SMTOSHSHUTTLEPROPS = 1467
    SMHYPERIONEXTERIOR = 1468
    SMHYPERIONEXTERIORLOW = 1469
    SMHYPERIONEXTERIORHOLOGRAM = 1470
    SMCHARCUTSCENES00 = 1471
    SMCHARCUTSCENES01 = 1472
    SMCHARCUTSCENES02 = 1473
    SMCHARCUTSCENES03 = 1474
    SMMARSARABARBRIEFINGSET = 1475
    SMMARSARABARBRIEFINGSET2 = 1476
    SMMARSARABARBRIEFINGSETLEFT = 1477
    SMMARSARABARBRIEFINGSETRIGHT = 1478
    SMMARSARABARBRIEFINGTVMAIN = 1479
    SMMARSARABARBRIEFINGTVMAIN2 = 1480
    SMMARSARABARBRIEFINGTVMAIN3 = 1481
    SMMARSARABARBRIEFINGTVPORTRAIT1 = 1482
    SMMARSARABARBRIEFINGTVPORTRAIT2 = 1483
    SMMARSARABARBRIEFINGTVPORTRAIT3 = 1484
    SMMARSARABARBRIEFINGTVPORTRAIT4 = 1485
    SMMARSARABARBRIEFINGTVPORTRAIT5 = 1486
    SMMARSARABARSET = 1487
    SMMARSARABARSET2 = 1488
    SMMARSARABARSTARMAPHS = 1489
    SMMARSARABARTVHS = 1490
    SMMARSARABARHYDRALISKSKULLHS = 1491
    SMMARSARABARCORKBOARDHS = 1492
    SMMARSARABARCORKBOARDBACKGROUND = 1493
    SMMARSARABARCORKBOARDITEM1HS = 1494
    SMMARSARABARCORKBOARDITEM2HS = 1495
    SMMARSARABARCORKBOARDITEM3HS = 1496
    SMMARSARABARCORKBOARDITEM4HS = 1497
    SMMARSARABARCORKBOARDITEM5HS = 1498
    SMMARSARABARCORKBOARDITEM6HS = 1499
    SMMARSARABARCORKBOARDITEM7HS = 1500
    SMMARSARABARCORKBOARDITEM8HS = 1501
    SMMARSARABARCORKBOARDITEM9HS = 1502
    SMMARSARABARBOTTLESHS = 1503
    SMVALERIANOBSERVATORYPROPS = 1504
    SMVALERIANOBSERVATORYSTARMAP = 1505
    SMBANSHEE = 1506
    SMVIKING = 1507
    SMARMORYBANSHEE = 1508
    SMARMORYDROPSHIP = 1509
    SMARMORYTANK = 1510
    SMARMORYVIKING = 1511
    SMARMORYSPIDERMINE = 1512
    SMARMORYGHOSTCRATE = 1513
    SMARMORYSPECTRECRATE = 1514
    SMARMORYBANSHEEPHCRATE = 1515
    SMARMORYDROPSHIPPHCRATE = 1516
    SMARMORYTANKPHCRATE = 1517
    SMARMORYVIKINGPHCRATE = 1518
    SMARMORYSPIDERMINEPHCRATE = 1519
    SMARMORYGHOSTCRATEPHCRATE = 1520
    SMARMORYSPECTRECRATEPHCRATE = 1521
    SMARMORYRIFLE = 1522
    SMDROPSHIP = 1523
    SMDROPSHIPBLUE = 1524
    SMHYPERIONARMORYVIKING = 1525
    SMCHARGATLINGGUN = 1526
    SMBOUNTYHUNTER = 1527
    SMCIVILIAN = 1528
    SMZERGEDHANSON = 1529
    SMLABASSISTANT = 1530
    SMHYPERIONARMORER = 1531
    SMUNNSCREEN = 1532
    NEWSARCTURUSINTERVIEWSET = 1533
    NEWSARCTURUSPRESSROOM = 1534
    SMDONNYVERMILLIONSET = 1535
    NEWSMEINHOFFREFUGEECENTER = 1536
    NEWSRAYNORLOGO = 1537
    NEWSTVEFFECT = 1538
    SMUNNCAMERA = 1539
    SMLEEKENOSET = 1540
    SMTVSTATIC = 1541
    SMDONNYVERMILLION = 1542
    SMDONNYVERMILLIONDEATH = 1543
    SMLEEKENO = 1544
    SMKATELOCKWELL = 1545
    SMMIKELIBERTY = 1546
    SMTERRANREADYROOMLEFTTV = 1547
    SMTERRANREADYROOMMAINTV = 1548
    SMTERRANREADYROOMRIGHTTV = 1549
    SMHYPERIONARMORYSTAGE1SET = 1550
    SMHYPERIONARMORYSTAGE1SET01 = 1551
    SMHYPERIONARMORYSTAGE1SET02 = 1552
    SMHYPERIONARMORYSTAGE1SET03 = 1553
    SMHYPERIONARMORYSPACELIGHTING = 1554
    SMHYPERIONARMORYSTAGE1TECHNOLOGYCONSOLEHS = 1555
    SMHYPERIONBRIDGESTAGE1BOW = 1556
    SMHYPERIONBRIDGESTAGE1SET = 1557
    SMHYPERIONBRIDGESTAGE1SET2 = 1558
    SMHYPERIONBRIDGESTAGE1SET3 = 1559
    SMHYPERIONBRIDGEHOLOMAP = 1560
    SMHYPERIONCANTINASTAGE1SET = 1561
    SMHYPERIONCANTINASTAGE1SET2 = 1562
    SMHYPERIONCANTINASTAGE1WALLPIECE = 1563
    SMHYPERIONBRIDGEPROPS = 1564
    SMHYPERIONCANTINAPROPS = 1565
    SMHYPERIONMEDLABPROPS = 1566
    SMHYPERIONMEDLABPROTOSSCRYOTUBE0HS = 1567
    SMHYPERIONMEDLABPROTOSSCRYOTUBE1HS = 1568
    SMHYPERIONMEDLABPROTOSSCRYOTUBE2HS = 1569
    SMHYPERIONMEDLABPROTOSSCRYOTUBE3HS = 1570
    SMHYPERIONMEDLABPROTOSSCRYOTUBE4HS = 1571
    SMHYPERIONMEDLABPROTOSSCRYOTUBE5HS = 1572
    SMHYPERIONMEDLABZERGCRYOTUBE0HS = 1573
    SMHYPERIONMEDLABZERGCRYOTUBE1HS = 1574
    SMHYPERIONMEDLABZERGCRYOTUBE2HS = 1575
    SMHYPERIONMEDLABZERGCRYOTUBE3HS = 1576
    SMHYPERIONMEDLABZERGCRYOTUBE4HS = 1577
    SMHYPERIONMEDLABZERGCRYOTUBE5HS = 1578
    SMHYPERIONMEDLABCRYOTUBEA = 1579
    SMHYPERIONMEDLABCRYOTUBEB = 1580
    SMHYPERIONCANTINASTAGE1EXITHS = 1581
    SMHYPERIONCANTINASTAGE1STAIRCASEHS = 1582
    SMHYPERIONCANTINASTAGE1TVHS = 1583
    SMHYPERIONCANTINASTAGE1ARCADEGAMEHS = 1584
    SMHYPERIONCANTINASTAGE1JUKEBOXHS = 1585
    SMHYPERIONCANTINASTAGE1CORKBOARDHS = 1586
    SMHYPERIONCANTINAPROGRESSFRAME = 1587
    SMHYPERIONCANTINAHYDRACLAWSHS = 1588
    SMHYPERIONCANTINAMERCCOMPUTERHS = 1589
    SMHYPERIONCANTINASTAGE1PROGRESS1HS = 1590
    SMHYPERIONCANTINASTAGE1PROGRESS2HS = 1591
    SMHYPERIONCANTINASTAGE1PROGRESS3HS = 1592
    SMHYPERIONCANTINASTAGE1PROGRESS4HS = 1593
    SMHYPERIONCANTINASTAGE1PROGRESS5HS = 1594
    SMHYPERIONCANTINASTAGE1PROGRESS6HS = 1595
    SMHYPERIONCORRIDORSET = 1596
    SMHYPERIONBRIDGESTAGE1BATTLEREPORTSHS = 1597
    SMHYPERIONBRIDGESTAGE1CENTERCONSOLEHS = 1598
    SMHYPERIONBRIDGESTAGE1BATTLECOMMANDHS = 1599
    SMHYPERIONBRIDGESTAGE1CANTINAHS = 1600
    SMHYPERIONBRIDGESTAGE1WINDOWHS = 1601
    SMHYPERIONMEDLABSTAGE1SET = 1602
    SMHYPERIONMEDLABSTAGE1SET2 = 1603
    SMHYPERIONMEDLABSTAGE1SETLIGHTS = 1604
    SMHYPERIONMEDLABSTAGE1CONSOLEHS = 1605
    SMHYPERIONMEDLABSTAGE1DOORHS = 1606
    SMHYPERIONMEDLABSTAGE1CRYSTALHS = 1607
    SMHYPERIONMEDLABSTAGE1ARTIFACTHS = 1608
    SMHYPERIONLABARTIFACTPART1HS = 1609
    SMHYPERIONLABARTIFACTPART2HS = 1610
    SMHYPERIONLABARTIFACTPART3HS = 1611
    SMHYPERIONLABARTIFACTPART4HS = 1612
    SMHYPERIONLABARTIFACTBASEHS = 1613
    SMSHADOWBOX = 1614
    SMCHARBATTLEZONESHADOWBOX = 1615
    SMCHARINTERACTIVESKYPARALLAX = 1616
    SMCHARINTERACTIVE02SKYPARALLAX = 1617
    SMRAYNORCOMMANDER = 1618
    SMADJUTANT = 1619
    SMADJUTANTHOLOGRAM = 1620
    SMMARAUDER = 1621
    SMFIREBAT = 1622
    SMMARAUDERPHCRATE = 1623
    SMFIREBATPHCRATE = 1624
    SMRAYNORMARINE = 1625
    SMMARINE01 = 1626
    SMMARINE02 = 1627
    SMMARINE02AOD = 1628
    SMMARINE03 = 1629
    SMMARINE04 = 1630
    SMCADE = 1631
    SMHALL = 1632
    SMBRALIK = 1633
    SMANNABELLE = 1634
    SMEARL = 1635
    SMKACHINSKY = 1636
    SMGENERICMALEGREASEMONKEY01 = 1637
    SMGENERICMALEGREASEMONKEY02 = 1638
    SMGENERICMALEOFFICER01 = 1639
    SMGENERICMALEOFFICER02 = 1640
    SMSTETMANN = 1641
    SMCOOPER = 1642
    SMHILL = 1643
    SMYBARRA = 1644
    SMVALERIANMENGSK = 1645
    SMARCTURUSMENGSK = 1646
    SMARCTURUSHOLOGRAM = 1647
    SMZERATUL = 1648
    SMHYDRALISK = 1649
    SMHYDRALISKDEAD = 1650
    SMMUTALISK = 1651
    SMZERGLING = 1652
    SCIENTIST = 1653
    MINERMALE = 1654
    CIVILIAN = 1655
    COLONIST = 1656
    CIVILIANFEMALE = 1657
    COLONISTFEMALE = 1658
    HUT = 1659
    COLONISTHUT = 1660
    INFESTABLEHUT = 1661
    INFESTABLECOLONISTHUT = 1662
    XELNAGASHRINEXIL = 1663
    PROTOSSRELIC = 1664
    PICKUPGRENADES = 1665
    PICKUPPLASMAGUN = 1666
    PICKUPPLASMAROUNDS = 1667
    PICKUPMEDICRECHARGE = 1668
    PICKUPMANARECHARGE = 1669
    PICKUPRESTORATIONCHARGE = 1670
    PICKUPCHRONORIFTDEVICE = 1671
    PICKUPCHRONORIFTCHARGE = 1672
    GASCANISTER = 1673
    GASCANISTERPROTOSS = 1674
    GASCANISTERZERG = 1675
    MINERALCRYSTAL = 1676
    PALLETGAS = 1677
    PALLETMINERALS = 1678
    NATURALGAS = 1679
    NATURALMINERALS = 1680
    NATURALMINERALSRED = 1681
    PICKUPHEALTH25 = 1682
    PICKUPHEALTH50 = 1683
    PICKUPHEALTH100 = 1684
    PICKUPHEALTHFULL = 1685
    PICKUPENERGY25 = 1686
    PICKUPENERGY50 = 1687
    PICKUPENERGY100 = 1688
    PICKUPENERGYFULL = 1689
    PICKUPMINES = 1690
    PICKUPPSISTORM = 1691
    CIVILIANCARSUNIT = 1692
    CRUISERBIKE = 1693
    TERRANBUGGY = 1694
    COLONISTVEHICLEUNIT = 1695
    COLONISTVEHICLEUNIT01 = 1696
    DUMPTRUCK = 1697
    TANKERTRUCK = 1698
    FLATBEDTRUCK = 1699
    COLONISTSHIPTHANSON02A = 1700
    PURIFIER = 1701
    INFESTEDARMORY = 1702
    INFESTEDBARRACKS = 1703
    INFESTEDBUNKER = 1704
    INFESTEDCC = 1705
    INFESTEDENGBAY = 1706
    INFESTEDFACTORY = 1707
    INFESTEDREFINERY = 1708
    INFESTEDSTARPORT = 1709
    INFESTEDMISSILETURRET = 1710
    LOGISTICSHEADQUARTERS = 1711
    INFESTEDSUPPLY = 1712
    TARSONISENGINE = 1713
    TARSONISENGINEFAST = 1714
    FREIGHTCAR = 1715
    CABOOSE = 1716
    HYPERION = 1717
    MENGSKHOLOGRAMBILLBOARD = 1718
    TRAYNOR01SIGNSDESTRUCTIBLE1 = 1719
    ABANDONEDBUILDING = 1720
    NOVA = 1721
    FOOD1000 = 1722
    PSIINDOCTRINATOR = 1723
    JORIUMSTOCKPILE = 1724
    ZERGDROPPOD = 1725
    TERRANDROPPOD = 1726
    COLONISTBIODOME = 1727
    COLONISTBIODOMEHALFBUILT = 1728
    INFESTABLEBIODOME = 1729
    INFESTABLECOLONISTBIODOME = 1730
    MEDIC = 1731
    VIKINGSKY_UNIT = 1732
    SS_FIGHTER = 1733
    SS_PHOENIX = 1734
    SS_CARRIER = 1735
    SS_BACKGROUNDZERG01 = 1736
    SS_BACKGROUNDSPACE00 = 1737
    SS_BACKGROUNDSPACE01 = 1738
    SS_BACKGROUNDSPACE02 = 1739
    SS_BACKGROUNDSPACEPROT00 = 1740
    SS_BACKGROUNDSPACEPROT01 = 1741
    SS_BACKGROUNDSPACEPROT02 = 1742
    SS_BACKGROUNDSPACEPROT03 = 1743
    SS_BACKGROUNDSPACEPROT04 = 1744
    SS_BACKGROUNDSPACEPROTOSSLARGE = 1745
    SS_BACKGROUNDSPACEZERGLARGE = 1746
    SS_BACKGROUNDSPACETERRANLARGE = 1747
    SS_BACKGROUNDSPACEZERG01 = 1748
    SS_BACKGROUNDSPACETERRAN01 = 1749
    BREACHINGCHARGE = 1750
    INFESTATIONSPIRE = 1751
    SPACEPLATFORMVENTSUNIT = 1752
    STONEZEALOT = 1753
    PRESERVERPRISON = 1754
    PORTJUNKER = 1755
    LEVIATHAN = 1756
    SWARMLING = 1757
    VALHALLADESTRUCTIBLEWALL = 1758
    NEWFOLSOMPRISONENTRANCE = 1759
    ODINBUILD = 1760
    NUKEPACK = 1761
    CHARDESTRUCTIBLEROCKCOVER = 1762
    CHARDESTRUCTIBLEROCKCOVERV = 1763
    CHARDESTRUCTIBLEROCKCOVERULDR = 1764
    CHARDESTRUCTIBLEROCKCOVERURDL = 1765
    MAARWARPINUNIT = 1766
    EGGPURPLE = 1767
    TRUCKFLATBEDUNIT = 1768
    TRUCKSEMIUNIT = 1769
    TRUCKUTILITYUNIT = 1770
    INFESTEDCOLONISTSHIP = 1771
    CASTANARDESTRUCTIBLEDEBRIS = 1772
    COLONISTTRANSPORT = 1773
    PRESERVERBASE = 1774
    PRESERVERA = 1775
    PRESERVERB = 1776
    PRESERVERC = 1777
    TAURENSPACEMARINE = 1778
    MARSARABRIDGEBLUR = 1779
    MARSARABRIDGEBRUL = 1780
    SHORTBRIDGEVERTICAL = 1781
    SHORTBRIDGEHORIZONTAL = 1782
    TESTHERO = 1783
    TESTSHOP = 1784
    HEALINGPOTIONTESTTARGET = 1785
    _4SLOTBAG = 1786
    _6SLOTBAG = 1787
    _8SLOTBAG = 1788
    _10SLOTBAG = 1789
    _12SLOTBAG = 1790
    _14SLOTBAG = 1791
    _16SLOTBAG = 1792
    _18SLOTBAG = 1793
    _20SLOTBAG = 1794
    _22SLOTBAG = 1795
    _24SLOTBAG = 1796
    REPULSERFIELD6 = 1797
    REPULSERFIELD8 = 1798
    REPULSERFIELD10 = 1799
    REPULSERFIELD12 = 1800
    DESTRUCTIBLEWALLCORNER45ULBL = 1801
    DESTRUCTIBLEWALLCORNER45ULUR = 1802
    DESTRUCTIBLEWALLCORNER45URBR = 1803
    DESTRUCTIBLEWALLCORNER45 = 1804
    DESTRUCTIBLEWALLCORNER45UR90L = 1805
    DESTRUCTIBLEWALLCORNER45UL90B = 1806
    DESTRUCTIBLEWALLCORNER45BL90R = 1807
    DESTRUCTIBLEWALLCORNER45BR90T = 1808
    DESTRUCTIBLEWALLCORNER90L45BR = 1809
    DESTRUCTIBLEWALLCORNER90T45BL = 1810
    DESTRUCTIBLEWALLCORNER90R45UL = 1811
    DESTRUCTIBLEWALLCORNER90B45UR = 1812
    DESTRUCTIBLEWALLCORNER90TR = 1813
    DESTRUCTIBLEWALLCORNER90BR = 1814
    DESTRUCTIBLEWALLCORNER90LB = 1815
    DESTRUCTIBLEWALLCORNER90LT = 1816
    DESTRUCTIBLEWALLDIAGONALBLUR = 1817
    DESTRUCTIBLEWALLDIAGONALBLURLF = 1818
    DESTRUCTIBLEWALLDIAGONALULBRLF = 1819
    DESTRUCTIBLEWALLDIAGONALULBR = 1820
    DESTRUCTIBLEWALLSTRAIGHTVERTICAL = 1821
    DESTRUCTIBLEWALLVERTICALLF = 1822
    DESTRUCTIBLEWALLSTRAIGHTHORIZONTAL = 1823
    DESTRUCTIBLEWALLSTRAIGHTHORIZONTALBF = 1824
    DEFENSEWALLE = 1825
    DEFENSEWALLS = 1826
    DEFENSEWALLW = 1827
    DEFENSEWALLN = 1828
    DEFENSEWALLNE = 1829
    DEFENSEWALLSW = 1830
    DEFENSEWALLNW = 1831
    DEFENSEWALLSE = 1832
    WRECKEDBATTLECRUISERHELIOSFINAL = 1833
    FIREWORKSBLUE = 1834
    FIREWORKSRED = 1835
    FIREWORKSYELLOW = 1836
    PURIFIERBLASTMARKUNIT = 1837
    ITEMGRAVITYBOMBS = 1838
    ITEMGRENADES = 1839
    ITEMMEDKIT = 1840
    ITEMMINES = 1841
    REAPERPLACEMENT = 1842
    QUEENZAGARAACGLUESCREENDUMMY = 1843
    OVERSEERZAGARAACGLUESCREENDUMMY = 1844
    STUKOVINFESTEDCIVILIANACGLUESCREENDUMMY = 1845
    STUKOVINFESTEDMARINEACGLUESCREENDUMMY = 1846
    STUKOVINFESTEDSIEGETANKACGLUESCREENDUMMY = 1847
    STUKOVINFESTEDDIAMONDBACKACGLUESCREENDUMMY = 1848
    STUKOVINFESTEDBANSHEEACGLUESCREENDUMMY = 1849
    SILIBERATORACGLUESCREENDUMMY = 1850
    STUKOVINFESTEDBUNKERACGLUESCREENDUMMY = 1851
    STUKOVINFESTEDMISSILETURRETACGLUESCREENDUMMY = 1852
    STUKOVBROODQUEENACGLUESCREENDUMMY = 1853
    ZEALOTFENIXACGLUESCREENDUMMY = 1854
    SENTRYFENIXACGLUESCREENDUMMY = 1855
    ADEPTFENIXACGLUESCREENDUMMY = 1856
    IMMORTALFENIXACGLUESCREENDUMMY = 1857
    COLOSSUSFENIXACGLUESCREENDUMMY = 1858
    DISRUPTORACGLUESCREENDUMMY = 1859
    OBSERVERFENIXACGLUESCREENDUMMY = 1860
    SCOUTACGLUESCREENDUMMY = 1861
    CARRIERFENIXACGLUESCREENDUMMY = 1862
    PHOTONCANNONFENIXACGLUESCREENDUMMY = 1863
    PRIMALZERGLINGACGLUESCREENDUMMY = 1864
    RAVASAURACGLUESCREENDUMMY = 1865
    PRIMALROACHACGLUESCREENDUMMY = 1866
    FIREROACHACGLUESCREENDUMMY = 1867
    PRIMALGUARDIANACGLUESCREENDUMMY = 1868
    PRIMALHYDRALISKACGLUESCREENDUMMY = 1869
    PRIMALMUTALISKACGLUESCREENDUMMY = 1870
    PRIMALIMPALERACGLUESCREENDUMMY = 1871
    PRIMALSWARMHOSTACGLUESCREENDUMMY = 1872
    CREEPERHOSTACGLUESCREENDUMMY = 1873
    PRIMALULTRALISKACGLUESCREENDUMMY = 1874
    TYRANNOZORACGLUESCREENDUMMY = 1875
    PRIMALWURMACGLUESCREENDUMMY = 1876
    HHREAPERACGLUESCREENDUMMY = 1877
    HHWIDOWMINEACGLUESCREENDUMMY = 1878
    HHHELLIONTANKACGLUESCREENDUMMY = 1879
    HHWRAITHACGLUESCREENDUMMY = 1880
    HHVIKINGACGLUESCREENDUMMY = 1881
    HHBATTLECRUISERACGLUESCREENDUMMY = 1882
    HHRAVENACGLUESCREENDUMMY = 1883
    HHBOMBERPLATFORMACGLUESCREENDUMMY = 1884
    HHMERCSTARPORTACGLUESCREENDUMMY = 1885
    HHMISSILETURRETACGLUESCREENDUMMY = 1886
    HIGHTEMPLARSKINPREVIEW = 1887
    WARPPRISMSKINPREVIEW = 1888
    SIEGETANKSKINPREVIEW = 1889
    LIBERATORSKINPREVIEW = 1890
    VIKINGSKINPREVIEW = 1891
    STUKOVINFESTEDTROOPERACGLUESCREENDUMMY = 1892
    XELNAGADESTRUCTIBLEBLOCKER6S = 1893
    XELNAGADESTRUCTIBLEBLOCKER6SE = 1894
    XELNAGADESTRUCTIBLEBLOCKER6E = 1895
    XELNAGADESTRUCTIBLEBLOCKER6NE = 1896
    XELNAGADESTRUCTIBLEBLOCKER6N = 1897
    XELNAGADESTRUCTIBLEBLOCKER6NW = 1898
    XELNAGADESTRUCTIBLEBLOCKER6W = 1899
    XELNAGADESTRUCTIBLEBLOCKER6SW = 1900
    XELNAGADESTRUCTIBLEBLOCKER8S = 1901
    XELNAGADESTRUCTIBLEBLOCKER8SE = 1902
    XELNAGADESTRUCTIBLEBLOCKER8E = 1903
    XELNAGADESTRUCTIBLEBLOCKER8NE = 1904
    XELNAGADESTRUCTIBLEBLOCKER8N = 1905
    XELNAGADESTRUCTIBLEBLOCKER8NW = 1906
    XELNAGADESTRUCTIBLEBLOCKER8W = 1907
    XELNAGADESTRUCTIBLEBLOCKER8SW = 1908
    SNOWGLAZESTARTERMP = 1909
    SHIELDBATTERY = 1910
    OBSERVERSIEGEMODE = 1911
    OVERSEERSIEGEMODE = 1912
    RAVENREPAIRDRONE = 1913
    HIGHTEMPLARWEAPONMISSILE = 1914
    CYCLONEMISSILELARGEAIRALTERNATIVE = 1915
    RAVENSCRAMBLERMISSILE = 1916
    RAVENREPAIRDRONERELEASEWEAPON = 1917
    RAVENSHREDDERMISSILEWEAPON = 1918
    INFESTEDACIDSPINESWEAPON = 1919
    INFESTORENSNAREATTACKMISSILE = 1920
    SNARE_PLACEHOLDER = 1921
    TYCHUSREAPERACGLUESCREENDUMMY = 1922
    TYCHUSFIREBATACGLUESCREENDUMMY = 1923
    TYCHUSSPECTREACGLUESCREENDUMMY = 1924
    TYCHUSMEDICACGLUESCREENDUMMY = 1925
    TYCHUSMARAUDERACGLUESCREENDUMMY = 1926
    TYCHUSWARHOUNDACGLUESCREENDUMMY = 1927
    TYCHUSHERCACGLUESCREENDUMMY = 1928
    TYCHUSGHOSTACGLUESCREENDUMMY = 1929
    TYCHUSSCVAUTOTURRETACGLUESCREENDUMMY = 1930
    ZERATULSTALKERACGLUESCREENDUMMY = 1931
    ZERATULSENTRYACGLUESCREENDUMMY = 1932
    ZERATULDARKTEMPLARACGLUESCREENDUMMY = 1933
    ZERATULIMMORTALACGLUESCREENDUMMY = 1934
    ZERATULOBSERVERACGLUESCREENDUMMY = 1935
    ZERATULDISRUPTORACGLUESCREENDUMMY = 1936
    ZERATULWARPPRISMACGLUESCREENDUMMY = 1937
    ZERATULPHOTONCANNONACGLUESCREENDUMMY = 1938
    RENEGADELONGBOLTMISSILEWEAPON = 1939
    VIKING = 1940
    RENEGADEMISSILETURRET = 1941
    PARASITICBOMBRELAYDUMMY = 1942
    REFINERYRICH = 1943
    MECHAZERGLINGACGLUESCREENDUMMY = 1944
    MECHABANELINGACGLUESCREENDUMMY = 1945
    MECHAHYDRALISKACGLUESCREENDUMMY = 1946
    MECHAINFESTORACGLUESCREENDUMMY = 1947
    MECHACORRUPTORACGLUESCREENDUMMY = 1948
    MECHAULTRALISKACGLUESCREENDUMMY = 1949
    MECHAOVERSEERACGLUESCREENDUMMY = 1950
    MECHALURKERACGLUESCREENDUMMY = 1951
    MECHABATTLECARRIERLORDACGLUESCREENDUMMY = 1952
    MECHASPINECRAWLERACGLUESCREENDUMMY = 1953
    MECHASPORECRAWLERACGLUESCREENDUMMY = 1954
    TROOPERMENGSKACGLUESCREENDUMMY = 1955
    MEDIVACMENGSKACGLUESCREENDUMMY = 1956
    BLIMPMENGSKACGLUESCREENDUMMY = 1957
    MARAUDERMENGSKACGLUESCREENDUMMY = 1958
    GHOSTMENGSKACGLUESCREENDUMMY = 1959
    SIEGETANKMENGSKACGLUESCREENDUMMY = 1960
    THORMENGSKACGLUESCREENDUMMY = 1961
    VIKINGMENGSKACGLUESCREENDUMMY = 1962
    BATTLECRUISERMENGSKACGLUESCREENDUMMY = 1963
    BUNKERDEPOTMENGSKACGLUESCREENDUMMY = 1964
    MISSILETURRETMENGSKACGLUESCREENDUMMY = 1965
    ARTILLERYMENGSKACGLUESCREENDUMMY = 1966
    LOADOUTSPRAY1 = 1967
    LOADOUTSPRAY2 = 1968
    LOADOUTSPRAY3 = 1969
    LOADOUTSPRAY4 = 1970
    LOADOUTSPRAY5 = 1971
    LOADOUTSPRAY6 = 1972
    LOADOUTSPRAY7 = 1973
    LOADOUTSPRAY8 = 1974
    LOADOUTSPRAY9 = 1975
    LOADOUTSPRAY10 = 1976
    LOADOUTSPRAY11 = 1977
    LOADOUTSPRAY12 = 1978
    LOADOUTSPRAY13 = 1979
    LOADOUTSPRAY14 = 1980
    PREVIEWBUNKERUPGRADED = 1981
    INHIBITORZONESMALL = 1982
    INHIBITORZONEMEDIUM = 1983
    INHIBITORZONELARGE = 1984
    ACCELERATIONZONESMALL = 1985
    ACCELERATIONZONEMEDIUM = 1986
    ACCELERATIONZONELARGE = 1987
    ACCELERATIONZONEFLYINGSMALL = 1988
    ACCELERATIONZONEFLYINGMEDIUM = 1989
    ACCELERATIONZONEFLYINGLARGE = 1990
    INHIBITORZONEFLYINGSMALL = 1991
    INHIBITORZONEFLYINGMEDIUM = 1992
    INHIBITORZONEFLYINGLARGE = 1993
    ASSIMILATORRICH = 1994
    EXTRACTORRICH = 1995
    MINERALFIELD450 = 1996
    MINERALFIELDOPAQUE = 1997
    MINERALFIELDOPAQUE900 = 1998
    COLLAPSIBLEROCKTOWERDEBRISRAMPLEFTGREEN = 1999
    COLLAPSIBLEROCKTOWERDEBRISRAMPRIGHTGREEN = 2000
    COLLAPSIBLEROCKTOWERPUSHUNITRAMPLEFTGREEN = 2001
    COLLAPSIBLEROCKTOWERPUSHUNITRAMPRIGHTGREEN = 2002
    COLLAPSIBLEROCKTOWERRAMPLEFTGREEN = 2003
    COLLAPSIBLEROCKTOWERRAMPRIGHTGREEN = 2004

    def __repr__(self) -> str:
        return f"UnitTypeId.{self.name}"


for item in UnitTypeId:
    globals()[item.name] = item
